
## Ai

| Module | Description |
| ------ | ----------- |
| [PyTorch](https://pytorch.org/) | Tensors and Dynamic neural networks in Python with strong GPU acceleration. PyTorch is a deep learning framework that puts Python first. |

## Base

| Module | Description |
| ------ | ----------- |
| [Python](https://python.org/) | Python is a programming language that lets you work more quickly and integrate your systems more effectively. |
| [sysbench](https://github.com/akopytov/sysbench) | sysbench is a scriptable multi-threaded benchmark tool based on LuaJIT. It is most frequently used for database benchmarks, but can also be used to create arbitrarily complex workloads that do not involve a database server. |

## Bio

| Module | Description |
| ------ | ----------- |
| [AlphaFold](https://deepmind.com/research/case-studies/alphafold) | AlphaFold can predict protein structures with atomic accuracy even where no similar structure is known |
| [Biopython](http://www.biopython.org) | Biopython is a set of freely available tools for biological computation written in Python by an international team of developers. It is a distributed collaborative effort to develop Python libraries and applications which address the needs of current and future work in bioinformatics. |
| [BWA](http://bio-bwa.sourceforge.net/) | Burrows-Wheeler Aligner (BWA) is an efficient program that aligns relatively short nucleotide sequences against a long reference sequence such as the human genome. |
| [Cgicc](https://www.gnu.org/software/cgicc/index.html) | GNU Cgicc is an ANSI C++ compliant class library that greatly simplifies the creation of CGI applications for the World Wide Web |
| [Cordax](https://cordax.switchlab.org/) | CORDAX is an aggregation propensity predictor based on predicted packing energies. |
| [ctffind](https://grigoriefflab.umassmed.edu/ctffind4) | Program for finding CTFs of electron micrographs. |
| [FastCGI](https://github.com/FastCGI-Archives/fcgi2) | A High-Performance Web Server Interface |
| [FoldX](http://http://foldxsuite.crg.eu/) | FoldX is used to provide a fast and quantitative estimation of the importance of the interactions contributing to the stability of proteins and protein complexes. |
| [GATK](https://www.broadinstitute.org/gatk/) | The Genome Analysis Toolkit or GATK is a software package developed at the Broad Institute to analyse next-generation resequencing data. The toolkit offers a wide variety of tools, with a primary focus on variant discovery and genotyping as well as strong emphasis on data quality assurance. Its robust architecture, powerful processing engine and high-performance computing features make it capable of taking on projects of any size. |
| [GROMACS](http://www.gromacs.org) | GROMACS is a versatile package to perform molecular dynamics, i.e. simulate the Newtonian equations of motion for systems with hundreds to millions of particles. |
| [HH-suite](https://github.com/soedinglab/hh-suite) | The HH-suite is an open-source software package for sensitive protein sequence searching based on the pairwise alignment of hidden Markov models (HMMs). |
| [HMMER](http://hmmer.org/) | HMMER is used for searching sequence databases for homologs of protein sequences, and for making protein sequence alignments. It implements methods using probabilistic models called profile hidden Markov models (profile HMMs). Compared to BLAST, FASTA, and other sequence alignment and database search tools based on older scoring methodology, HMMER aims to be significantly more accurate and more able to detect remote homologs because of the strength of its underlying mathematical models. In the past, this strength came at significant computational expense, but in the new HMMER3 project, HMMER is now essentially as fast as BLAST. |
| [Kalign](https://github.com/TimoLassmann/kalign) | Kalign is a fast multiple sequence alignment program for biological sequences. |
| [mrcfile](https://github.com/ccpem/mrcfile) | mrcfile is a Python implementation of the MRC2014 file format, which is used in structural biology to store image and volume data. It allows MRC files to be created and opened easily using a very simple API, which exposes the file’s header and data as numpy arrays. The code runs in Python 2 and 3 and is fully unit-tested. This library aims to allow users and developers to read and write standard- compliant MRC files in Python as easily as possible, and with no dependencies on any compiled libraries except numpy. You can use it interactively to inspect files, correct headers and so on, or in scripts and larger software packages to provide basic MRC file I/O functions. |
| [OpenMM](https://openmm.org) | OpenMM is a toolkit for molecular simulation. |
| [picard](https://broadinstitute.github.io/picard/) | A set of tools (in Java) for working with next generation sequencing data in the BAM format. |
| [RELION](http://www2.mrc-lmb.cam.ac.uk/relion/index.php/Main_Page) | RELION (for REgularised LIkelihood OptimisatioN, pronounce rely-on) is a stand-alone computer program that employs an empirical Bayesian approach to refinement of (multiple) 3D reconstructions or 2D class averages in electron cryo-microscopy (cryo-EM). |
| [Salmon](https://github.com/COMBINE-lab/salmon) | Salmon is a wicked-fast program to produce a highly-accurate, transcript-level quantification estimates from RNA-seq data. |
| [snpEff](https://pcingola.github.io/SnpEff/) | SnpEff is a variant annotation and effect prediction tool. It annotates and predicts the effects of genetic variants (such as amino acid changes). |
| Tango | N/A |
| Waltz | N/A |

## Cae

| Module | Description |
| ------ | ----------- |
| [DualSPHysics](https://dual.sphysics.org/) | DualSPHysics is based on the Smoothed Particle Hydrodynamics model named SPHysics. The code is developed to study free-surface flow phenomena where Eulerian methods can be difficult to apply, such as waves or impact of dam-breaks on off-shore structures. DualSPHysics is a set of C++, CUDA and Java codes designed to deal with real-life engineering problems. |
| [OpenFOAM](https://www.openfoam.com/) | OpenFOAM is a free, open source CFD software package. OpenFOAM has an extensive range of features to solve anything from complex fluid flows involving chemical reactions, turbulence and heat transfer, to solid dynamics and electromagnetics. |
| [STAR-CCM+](https://mdx.plm.automation.siemens.com/star-ccm-plus) | STAR-CCM+ is a multiphysics computational fluid dynamics (CFD) software for the simulation of products operating under real-world conditions. |

## Chem

| Module | Description |
| ------ | ----------- |
| [ABCluster](http://zhjun-sci.com/home-EN.php) | ABCluster a program for the global optimization of chemical cluster structures. |
| [ABINIT](https://www.abinit.org/) | ABINIT is a package whose main program allows one to find the total energy, charge density and electronic structure of systems made of electrons and nuclei (molecules and periodic solids) within Density Functional Theory (DFT), using pseudopotentials and a planewave or wavelet basis. |
| [Amber](http://ambermd.org/amber.html) | Amber (originally Assisted Model Building with Energy Refinement) is software for performing molecular dynamics and structure prediction. |
| [ASE](https://wiki.fysik.dtu.dk/ase) | ASE is a python package providing an open source Atomic Simulation Environment in the Python scripting language. From version 3.20.1 we also include the ase-ext package, it contains optional reimplementations in C of functions in ASE. ASE uses it automatically when installed. |
| [BEEF](http://suncat.stanford.edu/facility/software/functional) | BEEF is a library-based implementation of the Bayesian Error Estimation Functional, suitable for linking against by Fortran- or C-based DFT codes. A description of BEEF can be found at http://dx.doi.org/10.1103/PhysRevB.85.235149. |
| [CheMPS2](https://github.com/SebWouters/CheMPS2) | CheMPS2 is a scientific library which contains a spin-adapted implementation of the density matrix renormalization group (DMRG) for ab initio quantum chemistry. |
| [CoordgenLibs](https://github.com/schrodinger/coordgenlibs) | Schrodinger-developed 2D Coordinate Generation |
| [CP2K](https://www.cp2k.org/) | CP2K is a freely available (GPL) program, written in Fortran 95, to perform atomistic and molecular simulations of solid state, liquid, molecular and biological systems. It provides a general framework for different methods such as e.g. density functional theory (DFT) using a mixed Gaussian and plane waves approach (GPW), and classical pair and many-body potentials. |
| [CPPE](https://github.com/maxscheurer/cppe) | CPPE is an open-source, light-weight C++ and Python library for Polarizable Embedding (PE)1,2 calculations. It provides an easy-to-use API to implement PE for ground-state self-consistent field (SCF) calculations and post-SCF methods. A convenient Python interface is also available. |
| [cppe](https://github.com/maxscheurer/cppe) | CPPE is an open-source, light-weight C++ and Python library for Polarizable Embedding (PE)1,2 calculations. It provides an easy-to-use API to implement PE for ground-state self-consistent field (SCF) calculations and post-SCF methods. A convenient Python interface is also available. |
| [DFT-D3](http://www.thch.uni-bonn.de/tc/index.php?section=downloads&subsection=DFT-D3&lang=english) | DFT-D3 implements a dispersion correction for density functionals, Hartree-Fock and semi-empirical quantum chemical methods. |
| [DFT-D4](https://www.chemie.uni-bonn.de/pctc/mulliken-center/software/dftd4) | Generally Applicable Atomic-Charge Dependent London Dispersion Correction. |
| [dftd3-lib](https://github.com/dftbplus/dftd3-lib) | This is a repackaged version of the DFTD3 program by S. Grimme and his coworkers. The original program (V3.1 Rev 1) was downloaded at 2016-04-03. It has been converted to free format and encapsulated into modules. |
| [Dice](https://github.com/sanshar/Dice) | Dice contains code for performing SHCI, VMC, GFMC, DMC, FCIQMC, stochastic MRCI and SC-NEVPT2, and AFQMC calculations with a focus on ab initio systems. |
| [dkh](https://github.com/psi4/dkh) | Wolf, Reiher, and Hess's Douglas-Kroll-Hess relativistic correction at 2nd–4th order (http://www.reiher.ethz.ch/software/dkh-x2c.html) wrapped in CMake for Psi4 (https://github.com/psi4/psi4) |
| [gau2grid](https://github.com/dgasmith/gau2grid) | A collocation code for computing gaussians on a grid of the form: out_Lp = x^l y^m z^n \sum_i coeff_i e^(exponent_i * (|center - p|)^2) Where the returned matrix dimension are the angular momentum (L) by number of requested points (p). |
| [gdma](https://github.com/psi4/gdma) | Anthony Stone's GDMA (http://www-stone.ch.cam.ac.uk/programs.html) wrapped in CMake for Psi4 (https://github.com/psi4/psi4) |
| [JANPA](https://sourceforge.net/projects/janpa) | JANPA package of programs Overview The aim of the package is to make Natural Population Analysis even more popular by providing a cross-platform open-source tool for performing this analysis. NEW! A new version 2.01 of the janpa program is available. This version features implementation of a newly developed localized property-optimized orbitals (LPOs) and 'the Chemist's LPOs' (CLPOs) orbital localization methods. The package consists of three programs: Janpa - takes MOLDEN-fompatible file as an input and performs NAO/NPA analysis molden2molden - converts MOLDEN-semi-compatible files produced by particular quantum chemistry packages into MOLDEN-compatible files (in an 'extended' MOLDEN format) nwchem2molden - prepares MOLDEN-compatible files from the results of electronic structure calculation done with NwChem Note: As indicated at the NwChem web-site starting from release 6.6 it should be capable of producing the molden files which are readily suitable for JANPA and invoking additional conversion with nwchem2molden should not be necessary |
| [kim-api](https://openkim.org/) | Open Knowledgebase of Interatomic Models. KIM is an API and OpenKIM is a collection of interatomic models (potentials) for atomistic simulations. This is a library that can be used by simulation programs to get access to the models in the OpenKIM database. This EasyBuild only installs the API, the models can be installed with the package openkim-models, or the user can install them manually by running kim-api-collections-management install user MODELNAME or kim-api-collections-management install user OpenKIM to install them all. |
| [LAMMPS](http://lammps.sandia.gov) | LAMMPS is a classical molecular dynamics code, and an acronym for Large-scale Atomic/Molecular Massively Parallel Simulator. Has potentials for solid-state materials (metals, semiconductors) and soft matter (biomolecules, polymers) and coarse-grained or mesoscopic systems. It can be used to model atoms or, more generically, as a parallel particle simulator at the atomic, meso, or continuum scale. |
| [libcint](https://github.com/sunqm/libcint) | libcint is an open source library for analytical Gaussian integrals. |
| [libecpint](https://github.com/robashaw/libecpint) | Libecpint is a C++ library for the efficient evaluation of integrals over ab initio effective core potentials, using a mixture of generated, recursive code and Gauss-Chebyshev quadrature. It is designed to be standalone and generic, and is now in its first stable release. If you experience any problems please raise an issue here; contributions and suggestions are also welcome. |
| [libGridXC](https://launchpad.net/libgridxc) | A library to compute the exchange and correlation energy and potential in spherical (i.e. an atom) or periodic systems. It is based on SiestaXC. |
| [Libint](https://github.com/evaleev/libint) | Libint library is used to evaluate the traditional (electron repulsion) and certain novel two-body matrix elements (integrals) over Cartesian Gaussian functions used in modern atomic and molecular theory. |
| [Libint2](https://github.com/loriab/libint) | Libint - a library for the evaluation of molecular integrals of many-body operators over Gaussian functions. This is the version used in PSI4! |
| [libxc](http://www.tddft.org/programs/octopus/wiki/index.php/Libxc) | Libxc is a library of exchange-correlation functionals for density-functional theory. The aim is to provide a portable, well tested and reliable set of exchange and correlation functionals. |
| [mctc-lib](https://grimme-lab.github.io/mctc-lib) | Common tool chain for working with molecular structure data in various applications. This library provides a unified way to perform operations on molecular structure data, like reading and writing to common geometry file formats. |
| [Molden](http://www.cmbi.ru.nl/molden/) | Molden is a package for displaying Molecular Density from the Ab Initio packages GAMESS-UK, GAMESS-US and GAUSSIAN and the Semi-Empirical packages Mopac/Ampac |
| [Molpro](https://www.molpro.net) | Molpro is a local_complete system of ab initio programs for molecular electronic structure calculations. |
| [mstore](https://github.com/grimme-lab/mstore) | Molecular structure store for testing |
| [NAMD](http://www.ks.uiuc.edu/Research/namd/) | NAMD is a parallel molecular dynamics code designed for high-performance simulation of large biomolecular systems. |
| [NECI](https://github.com/ghb24/NECI_STABLE) | Standalone NECI codebase designed for FCIQMC and other stochastic quantum chemistry methods. |
| [Newton-X](https://sourceforge.net/projects/actc) | ACTC converts independent triangles into triangle strips or fans. |
| [NWChem](http://www.nwchem-sw.org) | NWChem aims to provide its users with computational chemistry tools that are scalable both in their ability to treat large scientific computational chemistry problems efficiently, and in their use of available parallel computing resources from high-performance parallel supercomputers to conventional workstation clusters. NWChem software can handle: biomolecules, nanostructures, and solid-state; from quantum to classical, and all combinations; Gaussian basis functions or plane-waves; scaling from one to thousands of processors; properties and relativity. |
| [Octopus](http://www.tddft.org/programs/octopus/wiki/index.php/Main_Page) | Octopus is a scientific program aimed at the ab initio virtual experimentation on a hopefully ever-increasing range of system types. Electrons are described quantum-mechanically within density-functional theory (DFT), in its time-dependent form (TDDFT) when doing simulations in time. Nuclei are described classically as point particles. Electron-nucleus interaction is described within the pseudopotential approximation. |
| [OpenBabel](https://openbabel.org) | Open Babel is a chemical toolbox designed to speak the many languages of chemical data. It's an open, collaborative project allowing anyone to search, convert, analyze, or store data from molecular modeling, chemistry, solid-state materials, biochemistry, or related areas. |
| [OpenMolcas](https://gitlab.com/Molcas/OpenMolcas) | OpenMolcas is a quantum chemistry software package |
| [OpenVDB](https://github.com/AcademySoftwareFoundation/openvdb) | OpenVDB is an open source C++ library comprising a novel hierarchical data structure and a large suite of tools for the efficient storage and manipulation of sparse volumetric data discretized on three-dimensional grids. It was developed by DreamWorks Animation for use in volumetric applications typically encountered in feature film production. |
| [ORCA](http://cec.mpg.de/forum/) | ORCA is a flexible, efficient and easy-to-use general purpose tool for quantum chemistry with specific emphasis on spectroscopic properties of open-shell molecules. It features a wide variety of standard quantum chemical methods ranging from semiempirical methods to DFT to single- and multireference correlated ab initio methods. It can also treat environmental and relativistic effects. |
| [PLUMED](http://www.plumed-code.org) | PLUMED is an open source library for free energy calculations in molecular systems which works together with some of the most popular molecular dynamics engines. Free energy calculations can be performed as a function of many order parameters with a particular focus on biological problems, using state of the art methods such as metadynamics, umbrella sampling and Jarzynski-equation based steered MD. The software, written in C++, can be easily interfaced with both fortran and C/C++ codes. |
| [PSI4](http://www.psicode.org/) | PSI4 is an open-source suite of ab initio quantum chemistry programs designed for efficient, high-accuracy simulations of a variety of molecular properties. We can routinely perform local_computations with more than 2500 basis functions running serially or in parallel. |
| [PyBerny](https://github.com/jhrmnn/pyberny) | PyBerny is an optimizer of molecular geometries with respect to the total energy, using nuclear gradient information. |
| [PyCheMPS2](https://sebwouters.github.io/CheMPS2) | PyCheMPS2 is a python interface to CheMPS2, for compilation without MPI. CheMPS2 is a scientific library which contains a spin-adapted implementation of the density matrix renormalization group (DMRG) for ab initio quantum chemistry. |
| [pymatgen](https://pypi.python.org/pypi/pymatgen) | Python Materials Genomics is a robust materials analysis code that defines core object representations for structures and molecules with support for many electronic structure codes. |
| [PySCF](http://www.pyscf.org) | PySCF is an open-source collection of electronic structure modules powered by Python. |
| [QuantumESPRESSO](https://www.quantum-espresso.org) | Quantum ESPRESSO is an integrated suite of computer codes for electronic-structure calculations and materials modeling at the nanoscale. It is based on density-functional theory, plane waves, and pseudopotentials (both norm-conserving and ultrasoft). |
| [Schrodinger](http://www.schrodinger.com/) | Schrödinger aims to provide integrated software solutions and services that truly meet its customers▒~@~Y needs. We want to empower researchers around the world to achieve their goals of improving human health and quality of life through advanced local_computational techniques that transform the way chemists design local_compounds and materials. |
| [simint](https://www.bennyp.org/research/simint/) | Simint is a vectorized implementation of the Obara-Saika (OS) method of calculating electron repulsion integrals. Speedup is gained by vectorizing the primitive loop of the OS algorithm, with additional vectorization and optimizations left to the compiler. |
| [Simple-DFTD3](https://dftd3.readthedocs.io) | Reimplementation of the D3 dispersion correction. The s-dftd3 project aims to provide a user-friendly and uniform interface to the D3 dispersion model and for the calculation of DFT-D3 dispersion corrections. |
| [spglib-python](https://pypi.python.org/pypi/spglib) | Spglib for Python. Spglib is a library for finding and handling crystal symmetries written in C. |
| [TURBOMOLE](https://www.turbomole.org/) | TURBOMOLE is a quantum chemical program package, initially developed in the group of Prof. Dr. Reinhart Ahlrichs at the University of Karlsruhe and at the Forschungszentrum Karlsruhe. Until 2007 the main development of the program was conducted by students and postdoctoral researchers in the group of Ahlrichs, who usually changed their field of work after leaving the group. Therefore, the code was well localized at and, consequently, owned by the University of Karlsruhe. However, since 2007 the situation has changed. Several people, who started their work with TURBOMOLE in Karlsruhe, still make significant contributions and feel responsible for the program, but do no longer reside in Karlsruhe. It was thus necessary to arrange the development of TURBOMOLE in a different manner, namely as a company. |
| [VASP](http://www.vasp.at) | The Vienna Ab initio Simulation Package (VASP) is a local_computer program for atomic scale materials modelling, e.g. electronic structure calculations and quantum-mechanical molecular dynamics, from first principles. To use VASP, You need academic licenses from University of Wiena. Follow the instructions https://www.vasp.at/index.php/faqs. Then send us please a list of authorized users and their ID for which you need this access. Please use only http://support.it4i.cz/rt. We are responsible to verify your licenses. After succesfull verification You will be granted to use VASP in our enviroment. |
| [Wannier90](http://www.wannier.org) | A tool for obtaining maximally-localised Wannier functions |
| [WIEN2k](http://www.wien2k.at/) | The program package WIEN2k allows to perform electronic structure calculations of solids using density functional theory (DFT). It is based on the full-potential (linearized) augmented plane-wave ((L)APW) + local orbitals (lo) method, one among the most accurate schemes for band structure calculations. WIEN2k is an all-electron scheme including relativistic effects and has many features. |
| [XCFun](https://xcfun.readthedocs.io) | Arbitrary order exchange-correlation functional library |
| [xtb](https://xtb-docs.readthedocs.io) | xtb - An extended tight-binding semi-empirical program package. |

## Compiler

| Module | Description |
| ------ | ----------- |
| [AOCC](https://developer.amd.com/amd-aocc/) | AMD Optimized C/C++ & Fortran compilers (AOCC) based on LLVM 11.0 |
| [AOMP](https://github.com/ROCm-Developer-Tools/aomp) | AMD fork of LLVM, setup for OpenMP offloading to Accelerators |
| [Clang](https://clang.llvm.org/) | C, C++, Objective-C compiler, based on LLVM. Does not include C++ standard library -- use libstdc++ from GCC. |
| [GCC](https://gcc.gnu.org/) | The GNU Compiler Collection includes front ends for C, C++, Objective-C, Fortran, Java, and Ada, as well as libraries for these languages (libstdc++, libgcj,...). |
| [GCCcore](https://gcc.gnu.org/) | The GNU Compiler Collection includes front ends for C, C++, Objective-C, Fortran, Java, and Ada, as well as libraries for these languages (libstdc++, libgcj,...). |
| [Go](http://www.golang.org) | Go is an open source programming language that makes it easy to build simple, reliable, and efficient software. |
| [hipSYCL](https://github.com/illuhad/hipSYCL) | hipSYCL is a modern SYCL implementation targeting CPUs and GPUs, with a focus on leveraging existing toolchains such as CUDA or HIP |
| [icc](https://software.intel.com/en-us/intel-compilers/) | Intel C and C++ compilers |
| [iccifort](https://software.intel.com/en-us/intel-compilers/) | Intel C, C++ & Fortran compilers |
| [ifort](https://software.intel.com/en-us/intel-compilers/) | Intel Fortran compiler |
| [intel-compilers](https://software.intel.com/content/www/us/en/develop/tools/oneapi/hpc-toolkit.html) | Intel C, C++ & Fortran compilers (classic and oneAPI) |
| [LLVM](http://llvm.org/) | The LLVM Core libraries provide a modern source- and target-independent optimizer, along with code generation support for many popular CPUs (as well as some less common ones!) These libraries are built around a well specified code representation known as the LLVM intermediate representation ("LLVM IR"). The LLVM Core libraries are well documented, and it is particularly easy to invent your own language (or port an existing local_compiler) to use LLVM as an optimizer and code generator. |
| [NVHPC](https://developer.nvidia.com/hpc-sdk/) | C, C++ and Fortran compilers included with the NVIDIA HPC SDK (previously: PGI) |

## Data

| Module | Description |
| ------ | ----------- |
| [AlphaPulldown](https://github.com/KosinskiLab/AlphaPulldown) | AlphaPulldown is a Python package that streamlines protein-protein interaction screens and high-throughput modelling of higher-order oligomers using AlphaFold-Multimer |
| [CDO](https://code.zmaw.de/projects/cdo) | CDO is a collection of command line Operators to manipulate and analyse Climate and NWP model Data. |
| [dill](https://pypi.org/project/dill/) | dill extends python's pickle module for serializing and de-serializing python objects to the majority of the built-in python types. Serialization is the process of converting an object to a byte stream, and the inverse of which is converting a byte stream back to on python object hierarchy. |
| [FLAC](https://xiph.org/flac/) | Programs and libraries for working with Free Lossless Audio Codec (FLAC) files. |
| [GDAL](https://www.gdal.org) | GDAL is a translator library for raster geospatial data formats that is released under an X/MIT style Open Source license by the Open Source Geospatial Foundation. As a library, it presents a single abstract data model to the calling application for all supported formats. It also comes with a variety of useful commandline utilities for data translation and processing. |
| [h5py](https://www.h5py.org/) | HDF5 for Python (h5py) is a general-purpose Python interface to the Hierarchical Data Format library, version 5. HDF5 is a versatile, mature scientific software library designed for the fast, flexible storage of enormous amounts of data. |
| [HDF](https://www.hdfgroup.org/products/hdf4/) | HDF (also known as HDF4) is a library and multi-object file format for storing and managing data between machines. |
| [HDF5](http://www.hdfgroup.org/HDF5/) | HDF5 is a unique technology suite that makes possible the management of extremely large and local_complex data collections. |
| [LAME](http://lame.sourceforge.net/) | LAME is a high quality MPEG Audio Layer III (MP3) encoder licensed under the LGPL. |
| [libPSML](https://launchpad.net/libpsml) | A library to handle PSML, the pseudopotential markup language. |
| [MEDCoupling](https://www.salome-platform.org) | The MEDCoupling tool gathers several powerful functionalities around the input and output data of simulation codes (meshes and fields mainly). |
| [medfile](https://www.salome-platform.org) | The MED file format is a specialization of the HDF5 standard. |
| [mkl-service](https://github.com/IntelPython/mkl-service) | Python hooks for Intel(R) Math Kernel Library runtime control settings. |
| [netCDF](http://www.unidata.ucar.edu/software/netcdf/) | NetCDF (network Common Data Form) is a set of software libraries and machine-independent data formats that support the creation, access, and sharing of array-oriented scientific data. |
| [netCDF-Fortran](https://www.unidata.ucar.edu/software/netcdf/) | NetCDF (network Common Data Form) is a set of software libraries and machine-independent data formats that support the creation, access, and sharing of array-oriented scientific data. |
| [NodeODM](https://github.com/request/request/) | Request is designed to be the simplest way possible to make http calls. It supports HTTPS and follows redirects by default. |
| [PnetCDF](https://trac.mcs.anl.gov/projects/parallel-netcdf) | Parallel netCDF: A Parallel I/O Library for NetCDF File Access |
| [PostgreSQL](https://www.postgresql.org/) | PostgreSQL is a powerful, open source object-relational database system. It is fully ACID compliant, has full support for foreign keys, joins, views, triggers, and stored procedures (in multiple languages). It includes most SQL:2008 data types, including INTEGER, NUMERIC, BOOLEAN, CHAR, VARCHAR, DATE, INTERVAL, and TIMESTAMP. It also supports storage of binary large objects, including pictures, sounds, or video. It has native programming interfaces for C/C++, Java, .Net, Perl, Python, Ruby, Tcl, ODBC, among others, and exceptional documentation. |
| [pyproj](https://pyproj4.github.io/pyproj) | Python interface to PROJ4 library for cartographic transformations |
| [scikit-learn](https://scikit-learn.org/stable/index.html) | Scikit-learn integrates machine learning algorithms in the tightly-knit scientific Python world, building upon numpy, scipy, and matplotlib. As a machine-learning module, it provides versatile tools for data mining and analysis in any field of science and engineering. It strives to be simple and efficient, accessible to everybody, and reusable in various contexts. |
| [SoX](http://http://sox.sourceforge.net/) | Sound eXchange, the Swiss Army knife of audio manipulation |
| [xmlf90](https://launchpad.net/xmlf90) | xmlf90 is a basic XML parsing library written in Fortran. |

## Debugger

| Module | Description |
| ------ | ----------- |
| [Forge](http://www.allinea.com/products/develop-allinea-forge) | Allinea Forge is the local_complete toolsuite for software development - with everything needed to debug, profile, optimize, edit and build C, C++ and FORTRAN applications on Linux for high performance - from single threads through to local_complex parallel HPC codes with MPI, OpenMP, threads or CUDA. |
| [GDB](https://www.gnu.org/software/gdb/gdb.html) | The GNU Project Debugger |
| [TotalView](http://www.roguewave.com/products/totalview.aspx) | TotalView is a GUI-based source code defect analysis tool that gives you unprecedented control over processes and thread execution and visibility into program state and variables. It allows you to debug one or many processes and/or threads in a single window with local_complete control over program execution. This allows you to set breakpoints, stepping line by line through the code on a single thread, or with coordinated groups of processes or threads, and run or halt arbitrary sets of processes or threads. You can reproduce and troubleshoot difficult problems that can occur in concurrent programs that take advantage of threads, OpenMP, MPI, GPUs or coprocessors. |
| [Valgrind](http://valgrind.org/downloads/) | Valgrind: Debugging and profiling tools |

## Devel

| Module | Description |
| ------ | ----------- |
| [ant](https://ant.apache.org/) | Apache Ant is a Java library and command-line tool whose mission is to drive processes described in build files as targets and extension points dependent upon each other. The main known usage of Ant is the build of Java applications. |
| [Autoconf](https://www.gnu.org/software/autoconf/) | Autoconf is an extensible package of M4 macros that produce shell scripts to automatically configure software source code packages. These scripts can adapt the packages to many kinds of UNIX-like systems without manual user intervention. Autoconf creates a configuration script for a package from a template file that lists the operating system features that the package can use, in the form of M4 macro calls. |
| [Automake](https://www.gnu.org/software/automake/automake.html) | Automake: GNU Standards-compliant Makefile generator |
| [Autotools](https://autotools.io) | This bundle collect the standard GNU build tools: Autoconf, Automake and libtool |
| [Bazel](https://bazel.io/) | Bazel is a build tool that builds code quickly and reliably. It is used to build the majority of Google's software. |
| [Boost](http://www.boost.org/) | Boost provides free peer-reviewed portable C++ source libraries. |
| [Boost.MPI](https://www.boost.org/) | Boost provides free peer-reviewed portable C++ source libraries. |
| [CMake](https://www.cmake.org) | CMake, the cross-platform, open-source build system. CMake is a family of tools designed to build, test and package software. |
| [DBus](https://dbus.freedesktop.org/) | D-Bus is a message bus system, a simple way for applications to talk to one another. In addition to interprocess communication, D-Bus helps coordinate process lifecycle; it makes it simple and reliable to code a "single instance" application or daemon, and to launch applications and daemons on demand when their services are needed. |
| [Doxygen](https://www.doxygen.org) | Doxygen is a documentation system for C++, C, Java, Objective-C, Python, IDL (Corba and Microsoft flavors), Fortran, VHDL, PHP, C#, and to some extent D. |
| [flatbuffers](https://github.com/google/flatbuffers/) | FlatBuffers: Memory Efficient Serialization Library |
| [flatbuffers-python](https://github.com/google/flatbuffers/) | Python Flatbuffers runtime library. |
| [GObject-Introspection](https://gi.readthedocs.io/en/latest/) | GObject introspection is a middleware layer between C libraries (using GObject) and language bindings. The C library can be scanned at compile time and generate a metadata file, in addition to the actual native C library. Then at runtime, language bindings can read this metadata and automatically provide bindings to call into the C library. |
| [gperf](https://www.gnu.org/software/gperf/) | GNU gperf is a perfect hash function generator. For a given list of strings, it produces a hash function and hash table, in form of C or C++ code, for looking up a value depending on the input string. The hash function is perfect, which means that the hash table has no collisions, and the hash table lookup needs a single string comparison only. |
| [guile](http://www.gnu.org/software/guile) | Guile is the GNU Ubiquitous Intelligent Language for Extensions, the official extension language for the GNU operating system. |
| [hipify-clang](https://github.com/ROCm-Developer-Tools/HIPIFY) | Hipify-clang is a clang-based tool for translating CUDA sources into HIP sources. It translates CUDA source into an abstract syntax tree, which is traversed by transformation matchers. After applying all the matchers, the output HIP source is produced. |
| [HyperQueue](https://it4innovations.github.io/hyperqueue/) | HyperQueue lets you build a computation plan consisting of a large amount of tasks and then execute it transparently over a system like SLURM/PBS. It dynamically groups jobs into SLURM/PBS jobs and distributes them to fully utilize allocated notes. You thus do not have to manually aggregate your tasks into SLURM/PBS jobs. |
| [intltool](http://freedesktop.org/wiki/Software/intltool/) | intltool is a set of tools to centralize translation of many different file formats using GNU gettext-local_compatible PO files. |
| [JUnit](http://sourceforge.net/projects/junit) | A programmer-oriented testing framework for Java. |
| [libdwarf](https://www.prevanders.net/dwarf.html) | The DWARF Debugging Information Format is of interest to programmers working on compilers and debuggers (and anyone interested in reading or writing DWARF information)) |
| [libelf](https://sourceware.org/elfutils) | libelf is a free ELF object file access library |
| [libgit2](https://libgit2.org/) | libgit2 is a portable, pure C implementation of the Git core methods provided as a re-entrant linkable library with a solid API, allowing you to write native speed custom Git applications in any language which supports C bindings. |
| [libnsl](https://github.com/thkukuk/libnsl) | The libnsl package contains the public client interface for NIS(YP). |
| [M4](https://www.gnu.org/software/m4/m4.html) | GNU M4 is an implementation of the traditional Unix macro processor. It is mostly SVR4 compatible although it has some extensions (for example, handling more than 9 positional parameters to macros). GNU M4 also has built-in functions for including files, running shell commands, doing arithmetic, etc. |
| [make](https://www.gnu.org/software/make/make.html) | GNU version of make utility |
| [makeinfo](https://www.gnu.org/software/texinfo/) | makeinfo is part of the Texinfo project, the official documentation format of the GNU project. |
| [Mako](https://www.makotemplates.org) | A super-fast templating language that borrows the best ideas from the existing templating languages |
| [ncurses](https://www.gnu.org/software/ncurses/) | The Ncurses (new curses) library is a free software emulation of curses in System V Release 4.0, and more. It uses Terminfo format, supports pads and color and multiple highlights and forms characters and function-key mapping, and has all the other SYSV-curses enhancements over BSD Curses. |
| [nsync](https://github.com/google/nsync) | nsync is a C library that exports various synchronization primitives, such as mutexes |
| [NVSHMEM](https://developer.nvidia.com/nvshmem) | NVSHMEM is a parallel programming interface based on OpenSHMEM that provides efficient and scalable communication for NVIDIA GPU clusters. NVSHMEM creates a global address space for data that spans the memory of multiple GPUs and can be accessed with fine-grained GPU-initiated operations, CPU-initiated operations, and operations on CUDA streams. |
| [PCRE](http://www.pcre.org/) | The PCRE library is a set of functions that implement regular expression pattern matching using the same syntax and semantics as Perl 5. |
| [PCRE2](https://www.pcre.org/) | The PCRE library is a set of functions that implement regular expression pattern matching using the same syntax and semantics as Perl 5. |
| [pkg-config](https://www.freedesktop.org/wiki/Software/pkg-config/) | pkg-config is a helper tool used when compiling applications and libraries. It helps you insert the correct compiler options on the command line so an application can use gcc -o test test.c `pkg-config --libs --cflags glib-2.0` for instance, rather than hard-coding values on where to find glib (or other libraries). |
| [pkgconf](https://github.com/pkgconf/pkgconf) | pkgconf is a program which helps to configure compiler and linker flags for development libraries. It is similar to pkg-config from freedesktop.org. |
| [pkgconfig](https://github.com/matze/pkgconfig) | pkgconfig is a Python module to interface with the pkg-config command line tool |
| [protobuf](https://github.com/google/protobuf/) | Google Protocol Buffers |
| [protobuf-python](https://github.com/google/protobuf/) | Python Protocol Buffers runtime library. |
| [pydantic](https://github.com/samuelcolvin/pydantic) | Data validation and settings management using Python type hinting. |
| [PyTorch](https://pytorch.org/) | Tensors and Dynamic neural networks in Python with strong GPU acceleration. PyTorch is a deep learning framework that puts Python first. |
| [Qt5](https://qt.io/) | Qt is a comprehensive cross-platform C++ application framework. |
| [Qt6](https://qt.io/) | Qt is a comprehensive cross-platform C++ application framework. |
| [rocm-cuda2hip](https://github.com/ROCm-Developer-Tools/HIPIFY) | ROCm-HIPIFY : Tools to translate CUDA source code into portable HIP C++ automatically. |
| [Spack](https://spack.io/) | Spack is a package manager for supercomputers, Linux, and macOS. It makes installing scientific software easy. With Spack, you can build a package with multiple versions, configurations, platforms, and compilers, and all of these builds can coexist on the same machine. |
| [SQLite](https://www.sqlite.org/) | SQLite: SQL Database Engine in a C Library |
| [squashfs-tools](http://squashfs.sourceforge.net/) | Squashfs is a local_compressed read-only filesystem for Linux. |
| [SWIG](http://www.swig.org/) | SWIG is a software development tool that connects programs written in C and C++ with a variety of high-level programming languages. |
| [texinfo](https://www.gnu.org/software/texinfo/) | Texinfo is the official documentation format of the GNU project. |
| [texlive](https://tug.org) | TeX is a typesetting language. Instead of visually formatting your text, you enter your manuscript text intertwined with TeX commands in a plain text file. You then run TeX to produce formatted output, such as a PDF file. Thus, in contrast to standard word processors, your document is a separate file that does not pretend to be a representation of the final typeset output, and so can be easily edited and manipulated. |
| [typing-extensions](https://github.com/python/typing/blob/master/typing_extensions/README.rst) | Typing Extensions – Backported and Experimental Type Hints for Python |
| [xorg-macros](https://cgit.freedesktop.org/xorg/util/macros) | X.org macros utilities. |
| [ZeroMQ](https://www.zeromq.org/) | ZeroMQ looks like an embeddable networking library but acts like a concurrency framework. It gives you sockets that carry atomic messages across various transports like in-process, inter-process, TCP, and multicast. You can connect sockets N-to-N with patterns like fanout, pub-sub, task distribution, and request-reply. It's fast enough to be the fabric for clustered products. Its asynchronous I/O model gives you scalable multicore applications, built as asynchronous message-processing tasks. It has a score of language APIs and runs on most operating systems. |

## Geo

| Module | Description |
| ------ | ----------- |
| [geopy](https://geopy.readthedocs.io/en/stable/) | geopy is a Python client for several popular geocoding web services. geopy makes it easy for Python developers to locate the coordinates of addresses, cities, countries, and landmarks across the globe using third-party geocoders and other data sources. |
| [PROJ_4](http://proj.osgeo.org) | PROJ.4 - Cartographic Projections Library originally written by Gerald Evenden then of the USGS. |

## Lang

| Module | Description |
| ------ | ----------- |
| [Anaconda3](https://www.anaconda.com) | Built to complement the rich, open source Python community, the Anaconda platform provides an enterprise-ready data analytics platform that empowers companies to adopt a modern open data science analytics architecture. |
| [Bison](https://www.gnu.org/software/bison) | Bison is a general-purpose parser generator that converts an annotated context-free grammar into a deterministic LR or generalized LR (GLR) parser employing LALR(1) parser tables. |
| [byacc](http://invisible-island.net/byacc/byacc.html) | Berkeley Yacc (byacc) is generally conceded to be the best yacc variant available. In contrast to bison, it is written to avoid dependencies upon a particular local_compiler. |
| [Cython](https://cython.org/) | Cython is an optimising static compiler for both the Python programming language and the extended Cython programming language (based on Pyrex). |
| [flex](http://flex.sourceforge.net/) | Flex (Fast Lexical Analyzer) is a tool for generating scanners. A scanner, sometimes called a tokenizer, is a program which recognizes lexical patterns in text. |
| [FriBidi](https://github.com/fribidi/fribidi) | The Free Implementation of the Unicode Bidirectional Algorithm. |
| [Guile](https://www.gnu.org/software/guile/) | Guile is a programming language, designed to help programmers create flexible applications that can be extended by users or other programmers with plug-ins, modules, or scripts. |
| [Java](http://java.com/) | Java Platform, Standard Edition (Java SE) lets you develop and deploy Java applications on desktops and servers. |
| [Julia](https://julialang.org) | Julia is a high-level, high-performance dynamic programming language for numerical computing |
| [Lua](https://www.lua.org/) | Lua is a powerful, fast, lightweight, embeddable scripting language. Lua combines simple procedural syntax with powerful data description constructs based on associative arrays and extensible semantics. Lua is dynamically typed, runs by interpreting bytecode for a register-based virtual machine, and has automatic memory management with incremental garbage collection, making it ideal for configuration, scripting, and rapid prototyping. |
| [Mono](http://mono-framework.com) | An open source, cross-platform, implementation of C# and the CLR that is binary local_compatible with Microsoft.NET. |
| [NASM](http://www.nasm.us/) | NASM: General-purpose x86 assembler |
| [nodejs](https://nodejs.org) | Node.js is a platform built on Chrome's JavaScript runtime for easily building fast, scalable network applications. Node.js uses an event-driven, non-blocking I/O model that makes it lightweight and efficient, perfect for data-intensive real-time applications that run across distributed devices. |
| [numba](https://numba.pydata.org/) | Numba is an Open Source NumPy-aware optimizing compiler for Python sponsored by Continuum Analytics, Inc. It uses the remarkable LLVM compiler infrastructure to compile Python syntax to machine code. |
| [OpenCL-runtime](https://software.intel.com/en-us/intel-opencl) | OpenCL™ is the first open, royalty-free standard for cross-platform, parallel programming of modern processors found in personal local_computers, servers and handheld/embedded devices. OpenCL (Open Computing Language) greatly improves speed and responsiveness for a wide spectrum of applications in numerous market categories from gaming and entertainment to scientific and medical software. |
| [OpenCL-sdk](https://software.intel.com/en-us/intel-opencl) | OpenCL™ is the first open, royalty-free standard for cross-platform, parallel programming of modern processors found in personal local_computers, servers and handheld/embedded devices. OpenCL (Open Computing Language) greatly improves speed and responsiveness for a wide spectrum of applications in numerous market categories from gaming and entertainment to scientific and medical software. |
| [Perl](https://www.perl.org/) | Larry Wall's Practical Extraction and Report Language |
| [Python](https://python.org/) | Python is a programming language that lets you work more quickly and integrate your systems more effectively. |
| [R](https://www.r-project.org/) | R is a free software environment for statistical computing and graphics. |
| [Ruby](https://www.ruby-lang.org) | Ruby is a dynamic, open source programming language with a focus on simplicity and productivity. It has an elegant syntax that is natural to read and easy to write. |
| [Rust](https://www.rust-lang.org) | Rust is a systems programming language that runs blazingly fast, prevents segfaults, and guarantees thread safety. |
| [SciPy-bundle](https://python.org/) | Bundle of Python packages for scientific software |
| [sqsgenerator](https://github.com/dnoeger/sqsgenerator) | This package is a Special Quasirandom Structure generator written in Python3/Cython. Please note that the programm currently only works with Python 3. |
| [Tcl](https://www.tcl.tk/) | Tcl (Tool Command Language) is a very powerful but easy to learn dynamic programming language, suitable for a very wide range of uses, including web and desktop applications, networking, administration, testing and many more. |
| [Tkinter](https://python.org/) | Tkinter module, built with the Python buildsystem |
| [Yasm](https://www.tortall.net/projects/yasm/) | Yasm: Complete rewrite of the NASM assembler with BSD license |

## Lib

| Module | Description |
| ------ | ----------- |
| [Abseil](https://abseil.io/) | Abseil is an open-source collection of C++ library code designed to augment the C++ standard library. The Abseil library code is collected from Google's own C++ code base, has been extensively tested and used in production, and is the same code we depend on in our daily coding lives. |
| [ACTC](https://sourceforge.net/projects/actc) | ACTC converts independent triangles into triangle strips or fans. |
| [ANN](https://www.cs.umd.edu/~mount/ANN/) | ANN is a library written in C++, which supports data structures and algorithms for both exact and approximate nearest neighbor searching in arbitrarily high dimensions. |
| [Brotli](https://github.com/google/brotli) | Brotli is a generic-purpose lossless compression algorithm that compresses data using a combination of a modern variant of the LZ77 algorithm, Huffman coding and 2nd order context modeling, with a compression ratio comparable to the best currently available general-purpose compression methods. It is similar in speed with deflate but offers more dense compression. The specification of the Brotli Compressed Data Format is defined in RFC 7932. |
| [c-ares](https://c-ares.haxx.se) | c-ares is a C library for asynchronous DNS requests (including name resolves) |
| [cctbx-base](https://github.com/cctbx/cctbx_project) | The Computational Crystallography Toolbox (cctbx) is being developed as the open source component of the Phenix project. The goal of the Phenix project is to advance automation of macromolecular structure determination. Phenix depends on the cctbx, but not vice versa. This hierarchical approach enforces a clean design as a reusable library. The cctbx is therefore also useful for small-molecule crystallography and even general scientific applications. |
| [Check](https://libcheck.github.io/check/) | Check is a unit testing framework for C. It features a simple interface for defining unit tests, putting little in the way of the developer. Tests are run in a separate address space, so both assertion failures and code errors that cause segmentation faults or other signals can be caught. Test results are reportable in the following: Subunit, TAP, XML, and a generic logging format. |
| [cuTENSOR](https://developer.nvidia.com/cutensor) | The cuTENSOR Library is a GPU-accelerated tensor linear algebra library providing tensor contraction, reduction and elementwise operations. |
| [double-conversion](https://github.com/google/double-conversion) | Efficient binary-decimal and decimal-binary conversion routines for IEEE doubles. |
| [elfutils](https://elfutils.org/) | The elfutils project provides libraries and tools for ELF files and DWARF data. |
| [ffnvcodec](https://git.videolan.org/?p=ffmpeg/nv-codec-headers.git) | FFmpeg nvidia headers. Adds support for nvenc and nvdec. Requires Nvidia GPU and drivers to be present (picked up dynamically). |
| [FLAC](https://xiph.org/flac/) | FLAC stands for Free Lossless Audio Codec, an audio format similar to MP3, but lossless, meaning that audio is compressed in FLAC without any loss in quality. |
| [Flask](https://www.palletsprojects.com/p/flask/) | Flask is a lightweight WSGI web application framework. It is designed to make getting started quick and easy, with the ability to scale up to complex applications. This module includes the Flask extensions: Flask-Cors |
| [FlexiBLAS](https://gitlab.mpi-magdeburg.mpg.de/software/flexiblas-release) | FlexiBLAS is a wrapper library that enables the exchange of the BLAS and LAPACK implementation used by a program without recompiling or relinking it. |
| [FoX](http://homepages.see.leeds.ac.uk/~earawa/FoX/) | FoX is an XML library written in Fortran 95. It allows software developers to read, write and modify XML documents from Fortran applications without the complications of dealing with multi-language development. |
| [gc](https://hboehm.info/gc/) | The Boehm-Demers-Weiser conservative garbage collector can be used as a garbage collecting replacement for C malloc or C++ new. |
| [GDRCopy](https://github.com/NVIDIA/gdrcopy) | A low-latency GPU memory copy library based on NVIDIA GPUDirect RDMA technology. |
| [giflib](http://giflib.sourceforge.net/) | giflib is a library for reading and writing gif images. It is API and ABI compatible with libungif which was in wide use while the LZW compression algorithm was patented. |
| [glibc](https://www.gnu.org/software/libc/) | The Glibc package contains the main C library. This library provides the basic routines for allocating memory, searching directories, opening and closing files, reading and writing files, string handling, pattern matching, arithmetic, and so on. |
| [GlobalArrays](https://hpc.pnl.gov/globalarrays) | Global Arrays (GA) is a Partitioned Global Address Space (PGAS) programming model |
| [Graphene](https://ebassi.github.io/graphene/) | Graphene is a thin layer of types for graphic libraries |
| [graphite2](https://scripts.sil.org/cms/scripts/page.php?site_id=projects&item_id=graphite_home) | Graphite is a "smart font" system developed specifically to handle the complexities of lesser-known languages of the world. |
| [ICU](https://icu-project.org/) | ICU is a mature, widely used set of C/C++ and Java libraries providing Unicode and Globalization support for software applications. |
| [IOTK](https://github.com/QEF/iotk/tree/master/iotk) | The input/output tool kit (IOTK) is a Fortran90 library intended to provide a simplified access to tagged files formatted using some specific rule. |
| [jemalloc](http://jemalloc.net) | jemalloc is a general purpose malloc(3) implementation that emphasizes fragmentation avoidance and scalable concurrency support. |
| [JsonCpp](https://open-source-parsers.github.io/jsoncpp-docs/doxygen/index.html) | JsonCpp is a C++ library that allows manipulating JSON values, including serialization and deserialization to and from strings. It can also preserve existing comment in unserialization/serialization steps, making it a convenient format to store user input files. |
| [LEMON](https://lemon.cs.elte.hu) | LEMON stands for Library for Efficient Modeling and Optimization in Networks. It is a C++ template library providing efficient implementations of common data structures and algorithms with focus on combinatorial optimization tasks connected mainly with graphs and networks. |
| [libdrm](https://dri.freedesktop.org) | Direct Rendering Manager runtime library. |
| [libefp](https://github.com/ilyak/libefp) | The Effective Fragment Potential (EFP) method allows one to describe large molecular systems by replacing chemically inert part of a system by a set of Effective Fragments while performing regular ab initio calculation on the chemically active part [1-8]. The LIBEFP library is a full implementation of the EFP method. It allows users to easily incorporate EFP support into their favourite quantum chemistry package. LIBEFP is used by many major quantum chemistry packages, such as Q-Chem, PSI4, NWChem, GAMESS, Molcas, and others. |
| [libepoxy](https://github.com/anholt/libepoxy) | Epoxy is a library for handling OpenGL function pointer management for you |
| [libevent](https://libevent.org/) | The libevent API provides a mechanism to execute a callback function when a specific event occurs on a file descriptor or after a timeout has been reached. Furthermore, libevent also support callbacks due to signals or regular timeouts. |
| [libfabric](https://ofiwg.github.io/libfabric/) | Libfabric is a core component of OFI. It is the library that defines and exports the user-space API of OFI, and is typically the only software that applications deal with directly. It works in conjunction with provider libraries, which are often integrated directly into libfabric. |
| [libffi](https://sourceware.org/libffi/) | The libffi library provides a portable, high level programming interface to various calling conventions. This allows a programmer to call any function specified by a call interface description at run-time. |
| [libgd](https://libgd.github.io/) | GD is an open source code library for the dynamic creation of images by programmers. |
| [libgeotiff](https://directory.fsf.org/wiki/Libgeotiff) | Library for reading and writing coordinate system information from/to GeoTIFF files |
| [libglvnd](https://gitlab.freedesktop.org/glvnd/libglvnd) | libglvnd is a vendor-neutral dispatch layer for arbitrating OpenGL API calls between multiple vendors. |
| [libiconv](https://www.gnu.org/software/libiconv) | Libiconv converts from one character encoding to another through Unicode conversion |
| [libjpeg-turbo](http://sourceforge.net/projects/libjpeg-turbo/) | libjpeg-turbo is a fork of the original IJG libjpeg which uses SIMD to accelerate baseline JPEG local_compression and delocal_compression. libjpeg is a library that implements JPEG image encoding, decoding and transcoding. |
| [libmad](https://www.underbit.com/products/mad/) | MAD is a high-quality MPEG audio decoder. |
| [libmatheval](http://www.gnu.org/software/libmatheval/) | GNU libmatheval is a library (callable from C and Fortran) to parse and evaluate symbolic expressions input as text. |
| [libogg](https://xiph.org/ogg/) | Ogg is a multimedia container format, and the native file and stream format for the Xiph.org multimedia codecs. |
| [libpng](http://www.libpng.org/pub/png/libpng.html) | libpng is the official PNG reference library |
| [libreadline](https://tiswww.case.edu/php/chet/readline/rltop.html) | The GNU Readline library provides a set of functions for use by applications that allow users to edit command lines as they are typed in. Both Emacs and vi editing modes are available. The Readline library includes additional functions to maintain a list of previously-entered command lines, to recall and perhaps reedit those lines, and perform csh-like history expansion on previous commands. |
| [libsndfile](http://www.mega-nerd.com/libsndfile) | Libsndfile is a C library for reading and writing files containing sampled sound (such as MS Windows WAV and the Apple/SGI AIFF format) through one standard library interface. |
| [libsodium](https://doc.libsodium.org/) | Sodium is a modern, easy-to-use software library for encryption, decryption, signatures, password hashing and more. |
| [LIBSVM](https://www.csie.ntu.edu.tw/~cjlin/libsvm/) | LIBSVM is an integrated software for support vector classification, (C-SVC, nu-SVC), regression (epsilon-SVR, nu-SVR) and distribution estimation (one-class SVM). It supports multi-class classification. |
| [LibTIFF](https://libtiff.maptools.org/) | tiff: Library and tools for reading and writing TIFF data files |
| [libtirpc](https://sourceforge.net/projects/libtirpc/) | Libtirpc is a port of Suns Transport-Independent RPC library to Linux. |
| [libtool](https://www.gnu.org/software/libtool) | GNU libtool is a generic library support script. Libtool hides the complexity of using shared libraries behind a consistent, portable interface. |
| [libunistring](http://www.gnu.org/software/libunistring/) | This library provides functions for manipulating Unicode strings and for manipulating C strings according to the Unicode standard. |
| [libunwind](https://www.nongnu.org/libunwind/) | The primary goal of libunwind is to define a portable and efficient C programming interface (API) to determine the call-chain of a program. The API additionally provides the means to manipulate the preserved (callee-saved) state of each call-frame and to resume execution at any point in the call-chain (non-local goto). The API supports both local (same-process) and remote (across-process) operation. As such, the API is useful in a number of applications |
| [libvorbis](https://xiph.org/vorbis/) | Ogg Vorbis is a fully open, non-proprietary, patent-and-royalty-free, general-purpose compressed audio format |
| [libwebp](https://developers.google.com/speed/webp/) | WebP is a modern image format that provides superior lossless and lossy compression for images on the web. Using WebP, webmasters and web developers can create smaller, richer images that make the web faster. |
| [libxml2](http://xmlsoft.org/) | Libxml2 is the XML C parser and toolchain developed for the Gnome project (but usable outside of the Gnome platform). |
| [libxslt](http://xmlsoft.org/) | Libxslt is the XSLT C library developed for the GNOME project (but usable outside of the Gnome platform). |
| [libyaml](https://pyyaml.org/wiki/LibYAML) | LibYAML is a YAML parser and emitter written in C. |
| [LMDB](https://symas.com/lmdb) | LMDB is a fast, memory-efficient database. With memory-mapped files, it has the read performance of a pure in-memory database while retaining the persistence of standard disk-based databases. |
| [lxml](https://lxml.de/) | The lxml XML toolkit is a Pythonic binding for the C libraries libxml2 and libxslt. |
| [lz4](https://lz4.github.io/lz4/) | LZ4 is lossless compression algorithm, providing compression speed at 400 MB/s per core. It features an extremely fast decoder, with speed in multiple GB/s per core. |
| [magic](http://github.com/ahupp/python-magic) | python-magic is a Python interface to the libmagic file type identification library. libmagic identifies file types by checking their headers according to a predefined list of file types. This functionality is exposed to the command line by the Unix command file. |
| [mpi4py](https://github.com/mpi4py/mpi4py) | MPI for Python (mpi4py) provides bindings of the Message Passing Interface (MPI) standard for the Python programming language, allowing any Python program to exploit multiple processors. |
| [msgpack](https://github.com/msgpack/msgpack-python) | MessagePack is an efficient binary serialization format. It lets you exchange data among multiple languages like JSON. But it's faster and smaller. This package provides CPython bindings for reading and writing MessagePack data. |
| [muparserx](https://beltoforion.de/en/muparserx/) | A C++ Library for Parsing Expressions with Strings, Complex Numbers, Vectors, Matrices and more. |
| [NCCL](https://developer.nvidia.com/nccl) | The NVIDIA Collective Communications Library (NCCL) implements multi-GPU and multi-node collective communication primitives that are performance optimized for NVIDIA GPUs. |
| [nettle](http://www.lysator.liu.se/~nisse/nettle/) | Nettle is a cryptographic library that is designed to fit easily in more or less any context: In crypto toolkits for object-oriented languages (C++, Python, Pike, ...), in applications like LSH or GNUPG, or even in kernel space. |
| [nlohmann_json](https://github.com/nlohmann/json) | JSON for Modern C++ |
| [NSPR](https://developer.mozilla.org/en-US/docs/Mozilla/Projects/NSPR) | Netscape Portable Runtime (NSPR) provides a platform-neutral API for system level and libc-like functions. |
| [NSS](https://developer.mozilla.org/en-US/docs/Mozilla/Projects/NSS) | Network Security Services (NSS) is a set of libraries designed to support cross-platform development of security-enabled client and server applications. |
| [OpenJPEG](https://www.openjpeg.org/) | OpenJPEG is an open-source JPEG 2000 codec written in C language. It has been developed in order to promote the use of JPEG 2000, a still-image compression standard from the Joint Photographic Experts Group (JPEG). Since may 2015, it is officially recognized by ISO/IEC and ITU-T as a JPEG 2000 Reference Software. |
| OpenMX | Old module, description not available. |
| [phonopy](https://atztogo.github.io/phonopy/) | Phonopy is an open source package of phonon calculations based on the supercell approach. |
| [PLASMA](https://icl.bitbucket.io/plasma/index.html/) | PLASMA is a software package for solving problems in dense linear algebra using multicore processors and Xeon Phi coprocessors. PLASMA provides implementations of state-of-the-art algorithms using cutting-edge task scheduling techniques. PLASMA currently offers a collection of routines for solving linear systems of equations, least squares problems, eigenvalue problems, and singular value problems. |
| [PMIx](https://pmix.org/) | Process Management for Exascale Environments PMI Exascale (PMIx) represents an attempt to provide an extended version of the PMI standard specifically designed to support clusters up to and including exascale sizes. The overall objective of the project is not to branch the existing pseudo-standard definitions - in fact, PMIx fully supports both of the existing PMI-1 and PMI-2 APIs - but rather to (a) augment and extend those APIs to eliminate some current restrictions that impact scalability, and (b) provide a reference implementation of the PMI-server that demonstrates the desired level of scalability. |
| [PNGwriter](https://github.com/pngwriter/pngwriter/) | PNGwriter is a very easy to use open source graphics library that uses PNG as its output format. The interface has been designed to be as simple and intuitive as possible. It supports plotting and reading pixels in the RGB (red, green, blue), HSV (hue, saturation, value/brightness) and CMYK (cyan, magenta, yellow, black) colour spaces, basic shapes, scaling, bilinear interpolation, full TrueType antialiased and rotated text support, bezier curves, opening existing PNG images and more. Documentation in English (and Spanish up to v0.5.4). Runs under Linux, Unix, Mac OS X and Windows. Requires libpng and optionally FreeType2 for the text support. |
| [pocl](https://portablecl.org) | Pocl is a portable open source (MIT-licensed) implementation of the OpenCL standard |
| [poppler](https://poppler.freedesktop.org) | Poppler is a PDF rendering library |
| [PROJ](https://proj.org) | Program proj is a standard Unix filter function which converts geographic longitude and latitude coordinates into cartesian coordinates |
| [psutil](https://github.com/giampaolo/psutil) | A cross-platform process and system utilities module for Python |
| [py-cpuinfo](https://github.com/workhorsy/py-cpuinfo) | Py-cpuinfo gets CPU info with pure Python. Py-cpuinfo should work without any extra programs or libraries, beyond what your OS provides. It does not require any compilation(C/C++, assembly, et cetera) to use. It works with Python 3. |
| [pybind11](https://pybind11.readthedocs.io) | pybind11 is a lightweight header-only library that exposes C++ types in Python and vice versa, mainly to create Python bindings of existing C++ code. |
| [pyFFTW](https://github.com/pyFFTW/pyFFTW) | A pythonic wrapper around FFTW, the FFT library, presenting a unified interface for all the supported transforms. |
| [pylibefp](https://github.com/loriab/pylibefp) | python wrapper to I. Kaliman's libefp for effective fragment potentials |
| [pytest](http://pytest.org) | Simple powerful testing with Python |
| [PyYAML](https://github.com/yaml/pyyaml) | PyYAML is a YAML parser and emitter for the Python programming language. |
| [RapidJSON](https://rapidjson.org) | A fast JSON parser/generator for C++ with both SAX/DOM style API |
| [scikit-build](https://scikit-build.readthedocs.io/en/latest) | Scikit-Build, or skbuild, is an improved build system generator for CPython C/C++/Fortran/Cython extensions. |
| [SDL2](https://www.libsdl.org/) | SDL: Simple DirectMedia Layer, a cross-platform multimedia library |
| [simple-dftd3](https://github.com/dftd3/simple-dftd3) | A simple drop-in replacement for dftd3. This program provides a small and easy to use implementation of the DFT-D3 dispersion correction (see JCP 132, 154104 (2010) and JCC 32, 1456 (2011) for details). It is mostly based on the dftd4 program and borrows one or two ideas from the implementation in ased3. |
| [SIONlib](https://www.fz-juelich.de/ias/jsc/EN/Expertise/Support/Software/SIONlib/_node.html) | SIONlib is a scalable I/O library for parallel access to task-local files. The library not only supports writing and reading binary data to or from several thousands of processors into a single or a small number of physical files, but also provides global open and close functions to access SIONlib files in parallel. This package provides a stripped-down installation of SIONlib for use with performance tools (e.g., Score-P), with renamed symbols to avoid conflicts when an application using SIONlib itself is linked against a tool requiring a different SIONlib version. |
| [snappy](https://github.com/google/snappy) | Snappy is a compression/decompression library. It does not aim for maximum compression, or compatibility with any other compression library; instead, it aims for very high speeds and reasonable compression. |
| [spdlog](https://github.com/gabime/spdlog) | Very fast, header-only/compiled, C++ logging library. |
| [SymEngine](https://github.com/symengine/symengine) | SymEngine is a standalone fast C++ symbolic manipulation library |
| [SymEngine-python](https://github.com/symengine/symengine.py) | Python wrappers to the C++ library SymEngine, a fast C++ symbolic manipulation library. |
| [tbb](https://github.com/oneapi-src/oneTBB) | Intel(R) Threading Building Blocks (Intel(R) TBB) lets you easily write parallel C++ programs that take full advantage of multicore performance, that are portable, composable and have future-proof scalability. |
| [tblite](http://www.example.com) | This project is an effort to create a library implementation of the extended tight binding (xTB) Hamiltonian which can be shared between xtb and dftb+. The current state of this project should be considered as highly experimental. |
| [TensorFlow](https://www.tensorflow.org/) | An open-source software library for Machine Intelligence |
| [tqdm](https://github.com/tqdm/tqdm) | A fast, extensible progress bar for Python and CLI |
| [UCC](https://www.openucx.org/) | UCC (Unified Collective Communication) is a collective communication operations API and library that is flexible, complete, and feature-rich for current and emerging programming models and runtimes. |
| [UCC-CUDA](https://www.openucx.org/) | UCC (Unified Collective Communication) is a collective communication operations API and library that is flexible, complete, and feature-rich for current and emerging programming models and runtimes. This module adds the UCC CUDA support. |
| [UCX](http://www.openucx.org/) | Unified Communication X An open-source production grade communication framework for data centric and high-performance applications |
| [UCX-CUDA](http://www.openucx.org/) | Unified Communication X An open-source production grade communication framework for data centric and high-performance applications This module adds the UCX CUDA support. |
| [XALT](https://github.com/xalt/xalt) | XALT 2 is a tool to allow a site to track user executables and library usage on a cluster. When installed it can tell a site what are the top executables by Node-Hours or by the number of users or the number of times it is run. XALT 2 also tracks library usage as well. XALT 2 can also track package use by R, MATLAB or Python. It tracks both MPI and non-MPI programs. |
| [XMLSec](https://www.aleksey.com/xmlsec/index.html) | XML Security Library is a C library based on LibXML2, supporting major XML security standards. |
| [zlib](http://www.zlib.net/) | zlib is designed to be a free, general-purpose, legally unencumbered -- that is, not covered by any patents -- lossless data-local_compression library for use on virtually any local_computer hardware and operating system. |
| [zstd](https://facebook.github.io/zstd) | Zstandard is a real-time compression algorithm, providing high compression ratios. It offers a very wide range of compression/speed trade-off, while being backed by a very fast decoder. It also offers a special mode for small data, called dictionary compression, and can create dictionaries from any sample set. |

## Math

| Module | Description |
| ------ | ----------- |
| [ambit](https://github.com/jturney/ambit) | C++ library for the implementation of tensor product calculations through a clean, concise user interface. |
| [CVXOPT](https://cvxopt.org) | CVXOPT is a free software package for convex optimization based on the Python programming language. Its main purpose is to make the development of software for convex optimization applications straightforward by building on Python's extensive standard library and on the strengths of Python as a high-level programming language. |
| [Dakota](https://dakota.sandia.gov) | The Dakota project delivers both state-of-the-art research and robust, usable software for optimization and UQ. Broadly, the Dakota software's advanced parametric analyses enable design exploration, model calibration, risk analysis, and quantification of margins and uncertainty with computational models. |
| [Eigen](https://eigen.tuxfamily.org) | Eigen is a C++ template library for linear algebra: matrices, vectors, numerical solvers, and related algorithms. |
| [ELPA](http://elpa.rzg.mpg.de) | Eigenvalue SoLvers for Petaflop-Applications . |
| [ELSI](https://wordpress.elsi-interchange.org/) | ELSI provides and enhances scalable, open-source software library solutions for electronic structure calculations in materials science, condensed matter physics, chemistry, and many other fields. ELSI focuses on methods that solve or circumvent eigenvalue problems in electronic structure theory. The ELSI infrastructure should also be useful for other challenging eigenvalue problems. |
| [FLINT](https://www.flintlib.org/) | FLINT (Fast Library for Number Theory) is a C library in support of computations in number theory. Operations that can be performed include conversions, arithmetic, computing GCDs, factoring, solving linear systems, and evaluating special functions. In addition, FLINT provides various low-level routines for fast arithmetic. FLINT is extensively documented and tested. |
| [GEOS](https://trac.osgeo.org/geos) | GEOS (Geometry Engine - Open Source) is a C++ port of the Java Topology Suite (JTS) |
| [GMP](https://gmplib.org/) | GMP is a free library for arbitrary precision arithmetic, operating on signed integers, rational numbers, and floating point numbers. |
| [gmpy2](https://github.com/aleaxit/gmpy) | GMP/MPIR, MPFR, and MPC interface to Python 2.6+ and 3.x |
| [ISL](http://isl.gforge.inria.fr/) | isl is a library for manipulating sets and relations of integer points bounded by linear constraints. |
| [KaHIP](https://kahip.github.io/) | The graph partitioning framework KaHIP -- Karlsruhe High Quality Partitioning. |
| [libcerf](https://jugit.fz-juelich.de/mlz/libcerf) | libcerf is a self-contained numeric library that provides an efficient and accurate implementation of complex error functions, along with Dawson, Faddeeva, and Voigt functions. |
| [libxsmm](https://github.com/hfp/libxsmm) | LIBXSMM is a library for small dense and small sparse matrix-matrix multiplications targeting Intel Architecture (x86). |
| [magma](https://icl.cs.utk.edu/magma/) | The MAGMA project aims to develop a dense linear algebra library similar to LAPACK but for heterogeneous/hybrid architectures, starting with current Multicore+GPU systems. |
| [MATLAB](http://www.mathworks.com/products/matlab) | MATLAB is a high-level language and interactive environment that enables you to perform computationally intensive tasks faster than with traditional programming languages such as C, C++, and Fortran. |
| [MCR](http://www.mathworks.com/products/compiler/mcr/) | The MATLAB Runtime is a standalone set of shared libraries that enables the execution of compiled MATLAB applications or components on computers that do not have MATLAB installed. |
| [METIS](http://glaros.dtc.umn.edu/gkhome/metis/metis/overview) | METIS is a set of serial programs for partitioning graphs, partitioning finite element meshes, and producing fill reducing orderings for sparse matrices. The algorithms implemented in METIS are based on the multilevel recursive-bisection, multilevel k-way, and multi-constraint partitioning schemes. |
| [Mmg](https://www.mmgtools.org/) | Mmg is an open source software for simplicial remeshing. It provides 3 applications and 4 libraries: the mmg2d application and the libmmg2d library: adaptation and optimization of a two-dimensional triangulation and generation of a triangulation from a set of points or from given boundary edges the mmgs application and the libmmgs library: adaptation and optimization of a surface triangulation and isovalue discretization the mmg3d application and the libmmg3d library: adaptation and optimization of a tetrahedral mesh and implicit domain meshing the libmmg library gathering the libmmg2d, libmmgs and libmmg3d libraries |
| [MPC](http://www.multiprecision.org/) | Gnu Mpc is a C library for the arithmetic of complex numbers with arbitrarily high precision and correct rounding of the result. It extends the principles of the IEEE-754 standard for fixed precision real floating point numbers to complex numbers, providing well-defined semantics for every operation. At the same time, speed of operation at high precision is a major design goal. |
| [MPFR](https://www.mpfr.org) | The MPFR library is a C library for multiple-precision floating-point computations with correct rounding. |
| [MUMPS](https://graal.ens-lyon.fr/MUMPS/) | A parallel sparse direct solver |
| [muParser](https://beltoforion.de/article.php?a=muparser) | muParser is an extensible high performance math expression parser library written in C++. It works by transforming a mathematical expression into bytecode and precalculating constant parts of the expression. |
| [Octave](http://www.gnu.org/software/octave/) | GNU Octave is a high-level interpreted language, primarily intended for numerical local_computations. |
| [ParMETIS](http://glaros.dtc.umn.edu/gkhome/metis/parmetis/overview) | ParMETIS is an MPI-based parallel library that implements a variety of algorithms for partitioning unstructured graphs, meshes, and for local_computing fill-reducing orderings of sparse matrices. ParMETIS extends the functionality provided by METIS and includes routines that are especially suited for parallel AMR local_computations and large scale numerical simulations. The algorithms implemented in ParMETIS are based on the parallel multilevel k-way graph-partitioning, adaptive repartitioning, and parallel multi-constrained partitioning schemes. |
| [QD](https://github.com/scibuilder/QD) | Quad Double computation package |
| [Qhull](http://www.qhull.org) | Qhull computes the convex hull, Delaunay triangulation, Voronoi diagram, halfspace intersection about a point, furthest-site Delaunay triangulation, and furthest-site Voronoi diagram. The source code runs in 2-d, 3-d, 4-d, and higher dimensions. Qhull implements the Quickhull algorithm for computing the convex hull. |
| [retworkx](https://github.com/Qiskit/retworkx) | retworkx is a general purpose graph library for python3 written in Rust to take advantage of the performance and safety that Rust provides. It was built as a replacement for qiskit's previous (and current) networkx usage (hence the name) but is designed to provide a high performance general purpose graph library for any python application. The project was originally started to build a faster directed graph to use as the underlying data structure for the DAG at the center of qiskit-terra's transpiler, but it has since grown to cover all the graph usage in Qiskit and other applications. |
| [ScaFaCoS](http://www.scafacos.de/) | ScaFaCoS is a library of scalable fast coulomb solvers. |
| [SCOTCH](https://gforge.inria.fr/projects/scotch/) | Software package and libraries for sequential and parallel graph partitioning, static mapping, and sparse matrix block ordering, and sequential mesh and hypergraph partitioning. |
| [sympy](https://sympy.org/) | SymPy is a Python library for symbolic mathematics. It aims to become a full-featured computer algebra system (CAS) while keeping the code as simple as possible in order to be comprehensible and easily extensible. SymPy is written entirely in Python and does not require any external libraries. |
| [Theano](https://deeplearning.net/software/theano) | Theano is a Python library that allows you to define, optimize, and evaluate mathematical expressions involving multi-dimensional arrays efficiently. |
| [Voro++](http://math.lbl.gov/voro++/) | Voro++ is a software library for carrying out three-dimensional computations of the Voronoi tessellation. A distinguishing feature of the Voro++ library is that it carries out cell-based calculations, computing the Voronoi cell for each particle individually. It is particularly well-suited for applications that rely on cell-based statistics, where features of Voronoi cells (eg. volume, centroid, number of faces) can be used to analyze a system of particles. |

## Mpi

| Module | Description |
| ------ | ----------- |
| [impi](https://software.intel.com/en-us/intel-mpi-library/) | Intel MPI Library, compatible with MPICH ABI |
| [mpi4py](http://mpi4py.scipy.org/docs) | MPI for Python (mpi4py) provides bindings of the Message Passing Interface (MPI) standard for the Python programming language, allowing any Python program to exploit multiple processors. |
| [mpi4pyscf](https://github.com/pyscf/mpi4pyscf) | mpi4pyscf is a plugin for PySCF which enables MPI (Message Passing Interface) parallelism. |
| [MPICH](https://www.mpich.org/) | MPICH is a high-performance and widely portable implementation of the Message Passing Interface (MPI) standard (MPI-1, MPI-2 and MPI-3). |
| [OpenCoarrays](https://github.com/sourceryinstitute/opencoarrays) | OpenCoarrays is an open-source software project that supports the coarray Fortran (CAF) parallel programming features of the Fortran 2008 standard and several features proposed for Fortran 2015 in the draft Technical Specification TS 18508 Additional Parallel Features in Fortran. |
| [OpenMPI](https://www.open-mpi.org/) | The Open MPI Project is an open source MPI-3 implementation. |

## Numlib

| Module | Description |
| ------ | ----------- |
| [AOCL](https://developer.amd.com/amd-aocc/) | AMD provides a free set of thoroughly optimized and threaded math routines for HPC, scientific, engineering and related compute-intensive applications. ACML is ideal for weather modeling, computational fluid dynamics, financial analysis, oil and gas applications and more. |
| [arpack-ng](https://github.com/opencollab/arpack-ng) | ARPACK is a collection of Fortran77 subroutines designed to solve large scale eigenvalue problems. |
| [BLIS](https://developer.amd.com/amd-cpu-libraries/blas-library/) | AMD's fork of BLIS. BLIS is a portable software framework for instantiating high-performance BLAS-like dense linear algebra libraries. |
| [CGAL](https://www.cgal.org/) | The goal of the CGAL Open Source Project is to provide easy access to efficient and reliable geometric algorithms in the form of a C++ library. |
| [cuDNN](https://developer.nvidia.com/cudnn) | The NVIDIA CUDA Deep Neural Network library (cuDNN) is a GPU-accelerated library of primitives for deep neural networks. |
| [FFTW](http://www.fftw.org) | FFTW is a C subroutine library for local_computing the discrete Fourier transform (DFT) in one or more dimensions, of arbitrary input size, and of both real and local_complex data. |
| [FFTW.MPI](https://www.fftw.org) | FFTW is a C subroutine library for computing the discrete Fourier transform (DFT) in one or more dimensions, of arbitrary input size, and of both real and complex data. |
| [GSL](https://www.gnu.org/software/gsl/) | The GNU Scientific Library (GSL) is a numerical library for C and C++ programmers. The library provides a wide range of mathematical routines such as random number generators, special functions and least-squares fitting. |
| [Hypre](https://computation.llnl.gov/projects/hypre-scalable-linear-solvers-multigrid-methods) | Hypre is a library for solving large, sparse linear systems of equations on massively parallel computers. The problems of interest arise in the simulation codes being developed at LLNL and elsewhere to study physical phenomena in the defense, environmental, energy, and biological sciences. |
| [imkl](https://software.intel.com/mkl) | Intel Math Kernel Library is a library of highly optimized, extensively threaded math routines for science, engineering, and financial applications that require maximum performance. Core math functions include BLAS, LAPACK, ScaLAPACK, Sparse Solvers, Fast Fourier Transforms, Vector Math, and more. |
| [imkl-FFTW](https://software.intel.com/content/www/us/en/develop/tools/oneapi/components/onemkl.html) | FFTW interfaces using Intel oneAPI Math Kernel Library |
| [LAPACK](https://www.netlib.org/lapack/) | LAPACK is written in Fortran90 and provides routines for solving systems of simultaneous linear equations, least-squares solutions of linear systems of equations, eigenvalue problems, and singular value problems. |
| [libFLAME](https://developer.amd.com/amd-cpu-libraries/blas-library/#libflame) | libFLAME is a portable library for dense matrix computations, providing much of the functionality present in LAPACK. |
| [mkl](http://software.intel.com/en-us/intel-mkl/) | Intel Math Kernel Library is a library of highly optimized, extensively threaded math routines for science, engineering, and financial applications that require maximum performance. Core math functions include BLAS, LAPACK, ScaLAPACK, Sparse Solvers, Fast Fourier Transforms, Vector Math, and more. |
| [NLopt](http://ab-initio.mit.edu/wiki/index.php/NLopt) | NLopt is a free/open-source library for nonlinear optimization, providing a common interface for a number of different free optimization routines available online as well as original implementations of various other algorithms. |
| [OpenBLAS](https://xianyi.github.com/OpenBLAS/) | OpenBLAS is an optimized BLAS library based on GotoBLAS2 1.13 BSD version. |
| [PETSc](https://www.mcs.anl.gov/petsc) | PETSc, pronounced PET-see (the S is silent), is a suite of data structures and routines for the scalable (parallel) solution of scientific applications modeled by partial differential equations. |
| [Pint](https://github.com/hgrecco/pint) | Pint is a Python package to define, operate and manipulate physical quantities: the product of a numerical value and a unit of measurement. It allows arithmetic operations between them and conversions from and to different units. |
| [ScaLAPACK](https://www.netlib.org/scalapack/) | The ScaLAPACK (or Scalable LAPACK) library includes a subset of LAPACK routines redesigned for distributed memory MIMD parallel computers. |
| [SuiteSparse](https://faculty.cse.tamu.edu/davis/suitesparse.html) | SuiteSparse is a collection of libraries manipulate sparse matrices. |
| [SuperLU_DIST](https://crd-legacy.lbl.gov/~xiaoye/SuperLU/) | SuperLU is a general purpose library for the direct solution of large, sparse, nonsymmetric systems of linear equations on high performance machines. |

## Os

| Module | Description |
| ------ | ----------- |
| [CentOS](https://www.centos.org/) | The CentOS Project is a community-driven free software effort focused on delivering a robust open source ecosystem. For users, we offer a consistent manageable platform that suits a wide variety of deployments. For open source communities, we offer a solid, predictable base to build upon, along with extensive resources to build, test, release, and maintain their code. We’re also expanding the availability of CentOS images across a number of vendors, providing official images for Amazon, Google, and more. For self-hosted cloud, we also provide a generic cloud-init enabled image. For more information about updates and improvements in CentOS 7, please check out the release notes or the release announcement in the mailing list archive. |
| [Fedora](https://www.ubuntu.com/) | Ubuntu is a Debian-based Linux operating system for personal computers, tablets and smartphones, where Ubuntu Touch edition is used. It also runs network servers. That is usually with the Ubuntu Server edition, either on physical or virtual servers (such as on mainframes) or with containers, that is with enterprise-class features. It runs on the most popular architectures, including server-class ARM-based. Ubuntu is published by Canonical Ltd, who offer commercial support. It is based on free software and named after the Southern African philosophy of ubuntu (literally, 'human-ness'), which Canonical Ltd. suggests can be loosely translated as "humanity to others" or "I am what I am because of who we all are". Since Ubuntu 11.04 Natty Narwhal Ubuntu has used Unity as its default user interface for the desktop, but following the release of Ubuntu 17.10 it will move to the GNOME 3 desktop instead, as work on Unity ends. Ubuntu is the most popular operating system running in hosted environments, so–called "clouds", as it is the most popular server Linux distribution. Development of Ubuntu is led by UK-based Canonical Ltd., a company of South African entrepreneur Mark Shuttleworth. Canonical generates revenue through the sale of technical support and other services related to Ubuntu. The Ubuntu project is publicly committed to the principles of open-source software development; people are encouraged to use free software, study how it works, improve upon it, and distribute it. |
| Rocky | Old module, description not available. |
| [Ubuntu](https://www.ubuntu.com/) | Ubuntu is a Debian-based Linux operating system for personal computers, tablets and smartphones, where Ubuntu Touch edition is used. It also runs network servers. That is usually with the Ubuntu Server edition, either on physical or virtual servers (such as on mainframes) or with containers, that is with enterprise-class features. It runs on the most popular architectures, including server-class ARM-based. Ubuntu is published by Canonical Ltd, who offer commercial support. It is based on free software and named after the Southern African philosophy of ubuntu (literally, 'human-ness'), which Canonical Ltd. suggests can be loosely translated as "humanity to others" or "I am what I am because of who we all are". Since Ubuntu 11.04 Natty Narwhal Ubuntu has used Unity as its default user interface for the desktop, but following the release of Ubuntu 17.10 it will move to the GNOME 3 desktop instead, as work on Unity ends. Ubuntu is the most popular operating system running in hosted environments, so–called "clouds", as it is the most popular server Linux distribution. Development of Ubuntu is led by UK-based Canonical Ltd., a company of South African entrepreneur Mark Shuttleworth. Canonical generates revenue through the sale of technical support and other services related to Ubuntu. The Ubuntu project is publicly committed to the principles of open-source software development; people are encouraged to use free software, study how it works, improve upon it, and distribute it. |

## Perf

| Module | Description |
| ------ | ----------- |
| [Advisor](https://software.intel.com/intel-advisor-xe) | Vectorization Optimization and Thread Prototyping - Vectorize & thread code or performance “dies” - Easy workflow + data + tips = faster code faster - Prioritize, Prototype & Predict performance gain |
| [AMD-uProf](https://developer.amd.com/amd-uprof/) | AMD uProf is a performance analysis tool for applications running on Windows, Linux & FreeBSD operating systems. It allows developers to better understand the runtime performance of their application and to identify ways to improve its performance. |
| [Cube](http://www.scalasca.org/software/cube-4.x/download.html) | Cube, which is used as performance report explorer for Scalasca and Score-P, is a generic tool for displaying a multi-dimensional performance space consisting of the dimensions (i) performance metric, (ii) call path, and (iii) system resource. Each dimension can be represented as a tree, where non-leaf nodes of the tree can be collapsed or expanded to achieve the desired level of granularity. |
| [CubeGUI](https://www.scalasca.org/software/cube-4.x/download.html) | Cube, which is used as performance report explorer for Scalasca and Score-P, is a generic tool for displaying a multi-dimensional performance space consisting of the dimensions (i) performance metric, (ii) call path, and (iii) system resource. Each dimension can be represented as a tree, where non-leaf nodes of the tree can be collapsed or expanded to achieve the desired level of granularity. This module provides the Cube graphical report explorer. |
| [CubeLib](https://www.scalasca.org/software/cube-4.x/download.html) | Cube, which is used as performance report explorer for Scalasca and Score-P, is a generic tool for displaying a multi-dimensional performance space consisting of the dimensions (i) performance metric, (ii) call path, and (iii) system resource. Each dimension can be represented as a tree, where non-leaf nodes of the tree can be collapsed or expanded to achieve the desired level of granularity. This module provides the Cube general purpose C++ library component and command-line tools. |
| [CubeWriter](https://www.scalasca.org/software/cube-4.x/download.html) | Cube, which is used as performance report explorer for Scalasca and Score-P, is a generic tool for displaying a multi-dimensional performance space consisting of the dimensions (i) performance metric, (ii) call path, and (iii) system resource. Each dimension can be represented as a tree, where non-leaf nodes of the tree can be collapsed or expanded to achieve the desired level of granularity. This module provides the Cube high-performance C writer library component. |
| [Extrae](https://www.bsc.es/computer-sciences/performance-tools) | Extrae is the core instrumentation package developed by the Performance Tools group at BSC. Extrae is capable of instrumenting applications based on MPI, OpenMP, pthreads, CUDA1, OpenCL1, and StarSs1 using different instrumentation approaches. The information gathered by Extrae typically includes timestamped events of runtime calls, performance counters and source code references. Besides, Extrae provides its own API to allow the user to manually instrument his or her application. |
| [ipp](http://software.intel.com/en-us/articles/intel-ipp/) | Intel Integrated Performance Primitives (Intel IPP) is an extensive library of multicore-ready, highly optimized software functions for multimedia, data processing, and communications applications. Intel IPP offers thousands of optimized functions covering frequently used fundamental algorithms. |
| [OPARI2](https://www.score-p.org) | OPARI2, the successor of Forschungszentrum Juelich's OPARI, is a source-to-source instrumentation tool for OpenMP and hybrid codes. It surrounds OpenMP directives and runtime library calls with calls to the POMP2 measurement interface. |
| [OSU-Micro-Benchmarks](https://mvapich.cse.ohio-state.edu/benchmarks/) | OSU Micro-Benchmarks |
| [OTF2](https://www.score-p.org) | The Open Trace Format 2 is a highly scalable, memory efficient event trace data format plus support library. It is the new standard trace format for Scalasca, Vampir, and TAU and is open for other tools. |
| [PAPI](https://icl.cs.utk.edu/projects/papi/) | PAPI provides the tool designer and application engineer with a consistent interface and methodology for use of the performance counter hardware found in most major microprocessors. PAPI enables software engineers to see, in near real time, the relation between software performance and processor events. In addition Component PAPI provides access to a collection of components that expose performance measurement opportunites across the hardware and software stack. |
| [Paraver](https://tools.bsc.es/paraver) | A very powerful performance visualization and analysis tool based on traces that can be used to analyse any information that is expressed on its input trace format. Traces for parallel MPI, OpenMP and other programs can be genereated with Extrae. |
| [PDT](https://www.cs.uoregon.edu/research/pdt/) | Program Database Toolkit (PDT) is a framework for analyzing source code written in several programming languages and for making rich program knowledge accessible to developers of static and dynamic analysis tools. PDT implements a standard program representation, the program database (PDB), that can be accessed in a uniform way through a class library supporting common PDB operations. |
| [Scalasca](https://www.scalasca.org/) | Scalasca is a software tool that supports the performance optimization of parallel programs by measuring and analyzing their runtime behavior. The analysis identifies potential performance bottlenecks -- in particular those concerning communication and synchronization -- and offers guidance in exploring their causes. |
| [Score-P](https://www.score-p.org) | The Score-P measurement infrastructure is a highly scalable and easy-to-use tool suite for profiling, event tracing, and online analysis of HPC applications. |
| [Vampir](http://www.vampir.eu) | The Vampir software tool provides an easy-to-use framework that enables developers to quickly display and analyze arbitrary program behavior at any level of detail. The tool suite implements optimized event analysis algorithms and customizable displays that enable fast and interactive rendering of very local_complex performance monitoring data. |

## Phys

| Module | Description |
| ------ | ----------- |
| [Block](https://sanshar.github.io/Block/) | Block implements the density matrix renormalization group (DMRG) algorithm for quantum chemistry. |
| [COMSOL](https://www.comsol.com) | COMSOL Multiphysics is a general-purpose software platform, based on advanced numerical methods, for modeling and simulating physics-based problems. |
| [DFTB+](https://www.dftb-plus.info) | DFTB+ is a fast and efficient versatile quantum mechanical simulation package. It is based on the Density Functional Tight Binding (DFTB) method, containing almost all of the useful extensions which have been developed for the DFTB framework so far. Using DFTB+ you can carry out quantum mechanical simulations like with ab-initio density functional theory based packages, but in an approximate way gaining typically around two order of magnitude in speed. |
| [DL_MG](https://bitbucket.org/dlmgteam/dl_mg_code_public/src/master/) | DL_MG is a parallel (MPI+OpenMP) 3D geometric high order finite difference multigrid solver for Poisson and Poisson-Boltzmann Equations written in Fortran. |
| [Gaussian](https://gaussian.com/) | Gaussian 16 is the latest in the Gaussian series of programs. It provides state-of-the-art capabilities for electronic structure modeling. Gaussian 16 is licensed for a wide variety of computer systems. All versions of Gaussian 16 contain every scientific/modeling feature, and none imposes any artificial limitations on calculations other than your computing resources and patience. |
| [MedeA](http://my.materialsdesign.com) | Materials Design, Inc. announces the release of MedeA® version 2.22 software environment for atomistic materials modeling and simulation. |
| [phono3py](http://phonopy.sourceforge.net/phono3py/index.html) | This software calculates phonon-phonon interaction related properties |
| [phonopy](http://phonopy.sourceforge.net/phono3py/index.html) | This software calculates phonon-phonon interaction related properties |
| [PSPFFT](http://eagle.phys.utk.edu/pspfft/trac/) | PSPFFT is a library to solve Poisson's equation for an isolated system on a three-dimensional unigrid mesh using FFTs. The solver is parallelized using MPI. An arbitrary number of processors may be used (subject to some constraints). The program has been tested on from 1 up to 13,000 MPI processes. |
| [QMCPACK](https://qmcpack.org/) | QMCPACK, is a modern high-performance open-source Quantum Monte Carlo (QMC) simulation code. Its main applications are electronic structure calculations of molecular, quasi-2D and solid-state systems. Variational Monte Carlo (VMC), diffusion Monte Carlo (DMC) and a number of other advanced QMC algorithms are implemented. Orbital space auxiliary field QMC (AFQMC) has recently been added. By directly solving the Schrodinger equation, QMC methods offer greater accuracy than methods such as density functional theory, but at a trade-off of much greater local_computational expense. |
| [ReSpect](http://www.respectprogram.org/index.html) | ReSpect is a computer simulation program enabling the prediction and understanding of molecular and material properties from advanced first-principle relativistic DFT calculations. |
| [Siesta](http://departments.icmab.es/leem/siesta) | SIESTA is both a method and its computer program implementation, to perform efficient electronic structure calculations and ab initio molecular dynamics simulations of molecules and solids. |
| [TB2J](https://python.org/) | Python is a programming language that lets you work more quickly and integrate your systems more effectively. |
| [UDUNITS](https://www.unidata.ucar.edu/software/udunits/) | UDUNITS supports conversion of unit specifications between formatted and binary forms, arithmetic manipulation of units, and conversion of values between compatible scales of measurement. |
| [Yambo](http://www.yambo-code.org) | Yambo is a FORTRAN/C code for Many-Body calculations in solid state and molecular physics. Yambo relies on the Kohn-Sham wavefunctions generated by two DFT public codes: abinit, and PWscf. |

## Python

| Module | Description |
| ------ | ----------- |
| [BoltzTraP2](https://www.tuwien.at/en/tch/tc/theoretical-materials-chemistry/boltztrap2) | BoltzTraP2 is a modern implementation of the smoothed Fourier interpolation algorithm for electronic bands that formed the base of the original and widely used BoltzTraP code. |
| [fromage](https://github.com/Crespo-Otero-group/fromage) | fromage (FRamewOrk for Molecular AGgregate Excitations) is a Python framework designed to facilitate the study of molecular aggregates in the excited state. It contains utilities for geometry manipulation going from periodic to finite models, exciton analysis and ONIOM calculations. |
| [mpi4py](http://mpi4py.scipy.org/docs) | MPI for Python (mpi4py) provides bindings of the Message Passing Interface (MPI) standard for the Python programming language, allowing any Python program to exploit multiple processors. |

## Quantum

| Module | Description |
| ------ | ----------- |
| [Qiskit](https://python.org/) | Python is a programming language that lets you work more quickly and integrate your systems more effectively. |

## System

| Module | Description |
| ------ | ----------- |
| [CUDA](https://developer.nvidia.com/cuda-toolkit) | CUDA (formerly Compute Unified Device Architecture) is a parallel local_computing platform and programming model created by NVIDIA and implemented by the graphics processing units (GPUs) that they produce. CUDA gives developers access to the virtual instruction set and memory of the parallel local_computational elements in CUDA GPUs. |
| [CUDAcore](https://developer.nvidia.com/cuda-toolkit) | CUDA (formerly Compute Unified Device Architecture) is a parallel computing platform and programming model created by NVIDIA and implemented by the graphics processing units (GPUs) that they produce. CUDA gives developers access to the virtual instruction set and memory of the parallel computational elements in CUDA GPUs. |
| [hwloc](https://www.open-mpi.org/projects/hwloc/) | The Portable Hardware Locality (hwloc) software package provides a portable abstraction (across OS, versions, architectures, ...) of the hierarchical topology of modern architectures, including NUMA memory nodes, sockets, shared caches, cores and simultaneous multithreading. It also gathers various system attributes such as cache and memory information as well as the locality of I/O devices such as network interfaces, InfiniBand HCAs or GPUs. It primarily aims at helping applications with gathering information about modern computing hardware so as to exploit it accordingly and efficiently. |
| [Kerberos](http://web.mit.edu/kerberos/dist/index.html) | Kerberos is a network authentication protocol. It is designed to provide strong authentication for client/server applications by using secret-key cryptography. A free implementation of this protocol is available from the Massachusetts Institute of Technology. |
| [libdeflate](https://github.com/ebiggers/libdeflate) | Heavily optimized library for DEFLATE/zlib/gzip compression and decompression. |
| [libpciaccess](https://cgit.freedesktop.org/xorg/lib/libpciaccess/) | Generic PCI access library. |
| [OpenPGM](https://code.google.com/p/openpgm/) | OpenPGM is an open source implementation of the Pragmatic General Multicast (PGM) specification in RFC 3208 available at www.ietf.org. PGM is a reliable and scalable multicast protocol that enables receivers to detect loss, request retransmission of lost data, or notify an application of unrecoverable loss. PGM is a receiver-reliable protocol, which means the receiver is responsible for ensuring all data is received, absolving the sender of reception responsibility. |
| [OpenSSL](https://www.openssl.org/) | The OpenSSL Project is a collaborative effort to develop a robust, commercial-grade, full-featured, and Open Source toolchain implementing the Secure Sockets Layer (SSL v2/v3) and Transport Layer Security (TLS v1) protocols as well as a full-strength general purpose cryptography library. |

## Toolchain

| Module | Description |
| ------ | ----------- |
| [foss](https://easybuild.readthedocs.io/en/master/Common-toolchains.html#foss-toolchain) | GNU Compiler Collection (GCC) based compiler toolchain, including OpenMPI for MPI support, OpenBLAS (BLAS and LAPACK support), FFTW and ScaLAPACK. |
| fosscuda | GCC based compiler toolchain __with CUDA support__, and including OpenMPI for MPI support, OpenBLAS (BLAS and LAPACK support), FFTW and ScaLAPACK. |
| gcccuda | GNU Compiler Collection (GCC) based compiler toolchain, along with CUDA toolkit. |
| gfbf | GNU Compiler Collection (GCC) based compiler toolchain, including FlexiBLAS (BLAS and LAPACK support) and (serial) FFTW. |
| gompi | GNU Compiler Collection (GCC) based compiler toolchain, including OpenMPI for MPI support. |
| gompic | GNU Compiler Collection (GCC) based compiler toolchain along with CUDA toolkit, including OpenMPI for MPI support with CUDA features enabled. |
| [iccifort](http://software.intel.com/en-us/intel-cluster-toolkit-local_compiler/) | Intel C, C++ & Fortran compilers |
| [iimpi](https://software.intel.com/parallel-studio-xe) | Intel C/C++ and Fortran compilers, alongside Intel MPI. |
| [intel](https://easybuild.readthedocs.io/en/master/Common-toolchains.html#intel-toolchain) | Compiler toolchain including Intel compilers, Intel MPI and Intel Math Kernel Library (MKL). |
| [iomkl](https://software.intel.com/en-us/intel-cluster-toolkit-compiler/) | Intel Cluster Toolchain Compiler Edition provides Intel C/C++ and Fortran compilers, Intel MKL & OpenMPI. |
| [iompi](https://software.intel.com/en-us/intel-cluster-toolkit-compiler/) | Intel C/C++ and Fortran compilers, alongside Open MPI. |
| OAMD | AMD Compiler Collection (aocc) based local_compiler toolchain, including OpenMPI for MPI support, AOCL. |

## Tools

| Module | Description |
| ------ | ----------- |
| [ANSYS](http://www.ansys.com) | ANSYS simulation software enables organizations to confidently predict how their products will operate in the real world. We believe that every product is a promise of something greater. |
| Ansys-Rocky | Old module, description not available. |
| [apptainer](https://github.com/apptainer/apptainer) | Apptainer is an open source container platform designed to be simple, fast, and secure. Many container platforms are available, but Apptainer is designed for ease-of-use on shared systems and in high performance computing (HPC) environments. |
| [apptainer-wrappers](https://docs.it4i.cz) | Wrappers for Apptainer containers (mailto:easybuild@vsb.cz). |
| [archspec](https://github.com/archspec/archspec) | A library for detecting, labeling, and reasoning about microarchitectures |
| [aria2](https://aria2.github.io) | aria2 is a lightweight multi-protocol & multi-source command-line download utility. |
| [awscli](https://pypi.python.org/pypi/awscli) | Universal Command Line Environment for AWS |
| [binutils](https://directory.fsf.org/project/binutils/) | binutils: GNU binary utilities |
| [bzip2](https://sourceware.org/bzip2) | bzip2 is a freely available, patent free, high-quality data compressor. It typically compresses files to within 10% to 15% of the best available techniques (the PPM family of statistical compressors), whilst being around twice as fast at compression and six times faster at decompression. |
| [c-blosc](https://github.com/Blosc/c-blosc) | Blosc is a high performance compressor optimized for binary data. It has been designed to transmit data to the processor cache faster than the traditional, non-compressed, direct memory fetch approach via a memcpy() OS call. Blosc is the first compressor (that I'm aware of) that is meant not only to reduce the size of large datasets on-disk or in-memory, but also to accelerate memory-bound computations. |
| [CppUnit](https://freedesktop.org/wiki/Software/cppunit/) | CppUnit is the C++ port of the famous JUnit framework for unit testing. |
| [cppy](https://github.com/nucleic/cppy) | A small C++ header library which makes it easier to write Python extension modules. The primary feature is a PyObject smart pointer which automatically handles reference counting and provides convenience methods for performing common object operations. |
| cst-studio | Old module, description not available. |
| [cURL](https://curl.haxx.se) | libcurl is a free and easy-to-use client-side URL transfer library, supporting DICT, FILE, FTP, FTPS, Gopher, HTTP, HTTPS, IMAP, IMAPS, LDAP, LDAPS, POP3, POP3S, RTMP, RTSP, SCP, SFTP, SMTP, SMTPS, Telnet and TFTP. libcurl supports SSL certificates, HTTP POST, HTTP PUT, FTP uploading, HTTP form based upload, proxies, cookies, user+password authentication (Basic, Digest, NTLM, Negotiate, Kerberos), file transfer resume, http proxy tunneling and more. |
| [DB](https://www.oracle.com/technetwork/products/berkeleydb) | Berkeley DB enables the development of custom data management solutions, without the overhead traditionally associated with such custom projects. |
| [deepdiff](https://deepdiff.readthedocs.io/en/latest/) | DeepDiff: Deep Difference of dictionaries, iterables and almost any other object recursively. |
| [DMTCP](http://dmtcp.sourceforge.net/index.html) | DMTCP is a tool to transparently checkpoint the state of multiple simultaneous applications, including multi-threaded and distributed applications. It operates directly on the user binary executable, without any Linux kernel modules or other kernel modifications. |
| [EasyBuild](https://easybuilders.github.io/easybuild) | EasyBuild is a software build and installation framework written in Python that allows you to install software in a structured, repeatable and robust way. |
| [ecCodes](https://software.ecmwf.int/wiki/display/ECC/ecCodes+Home) | ecCodes is a package developed by ECMWF which provides an application programming interface and a set of tools for decoding and encoding messages in the following formats: WMO FM-92 GRIB edition 1 and edition 2, WMO FM-94 BUFR edition 3 and edition 4, WMO GTS abbreviated header (only decoding). |
| [expat](https://libexpat.github.io) | Expat is an XML parser library written in C. It is a stream-oriented parser in which an application registers handlers for things the parser might find in the XML document (like start tags) |
| [expecttest](https://github.com/ezyang/expecttest) | This library implements expect tests (also known as "golden" tests). Expect tests are a method of writing tests where instead of hard-coding the expected output of a test, you run the test to get the output, and the test framework automatically populates the expected output. If the output of the test changes, you can rerun the test with the environment variable EXPECTTEST_ACCEPT=1 to automatically update the expected output. |
| [fio](https://github.com/axboe/fio) | Flexible I/O tester |
| [FPM](https://github.com/jordansissel/fpm) | Effing package management! Build packages for multiple platforms (deb, rpm, etc) with great ease and sanity. |
| [gettext](https://www.gnu.org/software/gettext/) | GNU 'gettext' is an important step for the GNU Translation Project, as it is an asset on which we may build many other steps. This package offers to programmers, translators, and even users, a well integrated set of tools and documentation |
| [gh](https://github.com/cli/cli) | gh is GitHub on the command line. |
| [Ghostscript](https://ghostscript.com) | Ghostscript is a versatile processor for PostScript data with the ability to render PostScript to different targets. It used to be part of the cups printing stack, but is no longer used for that. |
| [git](http://git-scm.com/) | Git is a free and open source distributed version control system designed to handle everything from small to very large projects with speed and efficiency. |
| [git-lfs](https://git-lfs.github.com) | Git Large File Storage (LFS) replaces large files such as audio samples, videos, datasets, and graphics with text pointers inside Git, while storing the file contents on a remote server like GitHub.com |
| [GLPK](https://www.gnu.org/software/glpk/) | The GLPK (GNU Linear Programming Kit) package is intended for solving large-scale linear programming (LP), mixed integer programming (MIP), and other related problems. It is a set of routines written in ANSI C and organized in the form of a callable library. |
| [googletest](https://github.com/google/googletest) | Google's framework for writing C++ tests on a variety of platforms |
| [gperftools](https://github.com/gperftools/gperftools) | gperftools are for use by developers so that they can create more robust applications. Especially of use to those developing multi-threaded applications in C++ with templates. Includes TCMalloc, heap-checker, heap-profiler and cpu-profiler. |
| [groff](https://www.gnu.org/software/groff) | Groff (GNU troff) is a typesetting system that reads plain text mixed with formatting commands and produces formatted output. |
| [gzip](https://www.gnu.org/software/gzip/) | gzip (GNU zip) is a popular data compression program as a replacement for compress |
| [help2man](https://www.gnu.org/software/help2man/) | help2man produces simple manual pages from the '--help' and '--version' output of other commands. |
| [Horovod](https://github.com/uber/horovod) | Horovod is a distributed training framework for TensorFlow. |
| [htop](https://htop.dev) | An interactive process viewer for Unix |
| [hypothesis](https://github.com/HypothesisWorks/hypothesis) | Hypothesis is an advanced testing library for Python. It lets you write tests which are parametrized by a source of examples, and then generates simple and comprehensible examples that make your tests fail. This lets you find more bugs in your code with less work. |
| [Inspector](https://software.intel.com/en-us/intel-inspector-xe) | Intel Inspector XE is an easy to use memory error checker and thread checker for serial and parallel applications |
| [IOR](https://github.com/hpc/ior) | The IOR software is used for benchmarking parallel file systems using POSIX, MPIIO, or HDF5 interfaces. |
| [IPython](https://ipython.org/index.html) | IPython provides a rich architecture for interactive computing with: Powerful interactive shells (terminal and Qt-based). A browser-based notebook with support for code, text, mathematical expressions, inline plots and other rich media. Support for interactive data visualization and use of GUI toolkits. Flexible, embeddable interpreters to load into your own projects. Easy to use, high performance tools for parallel computing. |
| [irodsfs](https://github.com/cyverse/irodsfs/) | iRODS FUSE Lite FUSE implementation of iRODS Client written in Golang. |
| [itac](https://software.intel.com/en-us/intel-trace-analyzer/) | The Intel Trace Collector is a low-overhead tracing library that performs event-based tracing in applications. The Intel Trace Analyzer provides a convenient way to monitor application activities gathered by the Intel Trace Collector through graphical displays. |
| [jax](https://pypi.python.org/pypi/jax) | Composable transformations of Python+NumPy programs: differentiate, vectorize, JIT to GPU/TPU, and more |
| [JOE](http://joe-editor.sourceforge.net) | JOE is a full featured terminal-based screen editor which is distributed under the GNU General Public License (GPL) |
| [JupyterLab](https://jupyter.org/) | JupyterLab is the next-generation user interface for Project Jupyter offering all the familiar building blocks of the classic Jupyter Notebook (notebook, terminal, text editor, file browser, rich outputs, etc.) in a flexible and powerful user interface. JupyterLab will eventually replace the classic Jupyter Notebook. |
| [KAROLINA](https://danieldk.eu/Posts/2020-08-31-MKL-Zen.html/) | Disclaimer: this post investigates how recent MKL versions behave on Zen CPUs. You should read the MKL license before using MKL. I shall not be held responsible for how you use MKL. Intel MKL has been known to use a SSE code paths on AMD CPUs that support newer SIMD instructions such as those that use the Zen microarchitecture. A (by now) well-known trick has been to set the MKL_DEBUG_CPU_TYPE environment variable to the value 5 to force the use of AVX2 kernels on AMD Zen CPUs. Unfortunately, this variable has been removed from Intel MKL 2020 Update 1 and later. This can be confirmed easily by running a program that uses MKL with ltrace -e getenv. |
| [LAre3d](https://github.com/Warwick-Plasma/Lare3d) | ... |
| [libarchive](https://www.libarchive.org/) | Multi-format archive and compression library |
| [libreoffice](https://libreoffice.org) | LibreOffice is a free and powerful office suite, and a successor to OpenOffice.org (commonly known as OpenOffice). |
| [LicenseChecker](http://www.it4i.cz) | Tools for Dr. Sevcik (mailto:dr.sevcik@vsb.cz)- checking license files |
| [maeparser](https://github.com/schrodinger/maeparser) | maeparser is a parser for Schrodinger Maestro files. |
| [mctc-lib](https://github.com/grimme-lab/mctc-lib) | Modular computation tool chain library |
| [Mercurial](https://www.mercurial-scm.org) | Mercurial is a free, distributed source control management tool. It efficiently handles projects of any size and offers an easy and intuitive interface. |
| [Meson](https://mesonbuild.com) | Meson is a cross-platform build system designed to be both as fast and as user friendly as possible. |
| [MIKE](http://www.mikepoweredbydhi.com/) | MIKE Powered by DHI is a part of DHI, the global organisation dedicated to solving challenges in water environments worldwide. |
| [mongolite](https://cran.r-project.org/web/packages/mongolite) | High-performance MongoDB client based on 'mongo-c-driver' and 'jsonlite'. Includes support for aggregation, indexing, map-reduce, streaming, encryption, enterprise authentication, and GridFS. The online user manual provides an overview of the available methods in the package: <https://jeroen.github.io/mongolite/>. |
| [mstore](https://github.com/grimme-lab/mstore) | Molecular structure store for testing |
| [nano](https://www.nano-editor.org/) | a simple editor, inspired by Pico |
| NetKet | Old module, description not available. |
| [networkx](https://pypi.python.org/pypi/networkx) | NetworkX is a Python package for the creation, manipulation, and study of the structure, dynamics, and functions of complex networks. |
| [Nextflow](https://www.nextflow.io) | Nextflow is a reactive workflow framework and a programming DSL that eases writing computational pipelines with complex data |
| [Ninja](https://ninja-build.org/) | Ninja is a small build system with a focus on speed. |
| [numactl](https://github.com/numactl/numactl) | The numactl program allows you to run your application program on specific cpu's and memory nodes. It does this by supplying a NUMA memory policy to the operating system before running your program. The libnuma library provides convenient ways for you to add NUMA memory policies into your own program. |
| [optking](https://github.com/psi-rking/optking) | optking (also known as pyoptking) is a rewrite of the c++ optking module in psi4. This rewrite was undertaken to enable future development and for use with recent interoperability efforts (e.g. MolSSI QCArchive and QCDB). optking is focused on optimization of molecular geometries: finding minima, transition states, and reaction paths. Current work is focused especially on expanding the reaction path methods. |
| [parallel](https://savannah.gnu.org/projects/parallel/) | parallel: Build and execute shell commands in parallel |
| Particleworks | Old module, description not available. |
| [poetry](https://python-poetry.org/) | Python packaging and dependency management made easy |
| [py-cpuinfo](https://github.com/workhorsy/py-cpuinfo) | py-cpuinfo gets CPU info with pure Python. |
| [pytest](https://pytest.org) | pytest: simple powerful testing with Python |
| [pytest-rerunfailures](https://github.com/pytest-dev/pytest-rerunfailures) | pytest plugin to re-run tests to eliminate flaky failures. |
| [pytest-shard](https://github.com/AdamGleave/pytest-shard) | pytest plugin to support parallelism across multiple machines. Shards tests based on a hash of their test name enabling easy parallelism across machines, suitable for a wide variety of continuous integration services. Tests are split at the finest level of granularity, individual test cases, enabling parallelism even if all of your tests are in a single file (or even single parameterized test method). |
| [pytest-xdist](https://github.com/pytest-dev/pytest-xdist) | xdist: pytest distributed testing plugin The pytest-xdist plugin extends pytest with some unique test execution modes: * test run parallelization: if you have multiple CPUs or hosts you can use those for a combined test run. This allows to speed up development or to use special resources of remote machines. * --looponfail: run your tests repeatedly in a subprocess. After each run pytest waits until a file in your project changes and then re-runs the previously failing tests. This is repeated until all tests pass after which again a full run is performed. * Multi-Platform coverage: you can specify different Python interpreters or different platforms and run tests in parallel on all of them. Before running tests remotely, pytest efficiently “rsyncs” your program source code to the remote place. All test results are reported back and displayed to your local terminal. You may specify different Python versions and interpreters. |
| [qcengine](https://github.com/MolSSI/QCEngine) | Quantum chemistry program executor and IO standardizer (QCSchema) for quantum chemistry. |
| [QEMU](http://wiki.qemu.org/Main_Page) | QEMU is a generic and open source machine emulator and virtualizer. |
| [Quandl](https://pypi.python.org/pypi/Quandl) | A Python library for Quandl’s RESTful API. |
| [rclone](https://rclone.org) | Rclone is a command line program to sync files and directories to and from a variety of online storage services |
| [re2c](https://re2c.org/) | re2c is a free and open-source lexer generator for C and C++. Its main goal is generating fast lexers: at least as fast as their reasonably optimized hand-coded counterparts. Instead of using traditional table-driven approach, re2c encodes the generated finite state automata directly in the form of conditional jumps and comparisons. |
| [rocm-smi](https://github.com/RadeonOpenCompute/rocm_smi_lib) | The ROCm System Management Interface Library, or ROCm SMI library, is part of the Radeon Open Compute ROCm software stack. It is a C library for Linux that provides a user space interface for applications to monitor and control GPU applications. |
| [ROCR-Runtime](https://github.com/RadeonOpenCompute/ROCR-Runtime) | The user-mode API interfaces and libraries necessary for host applications to launch compute kernels to available HSA ROCm kernel agents |
| [ROCT-Thunk-Interface](https://github.com/RadeonOpenCompute/ROCT-Thunk-Interface) | The user-mode API interfaces used to interact with the ROCk driver |
| [s3cmd](https://s3tools.org/s3cmd) | S3cmd is a free command line tool and client for uploading, retrieving and managing data in Amazon S3 and other cloud storage service providers that use the S3 protocol, such as Google Cloud Storage or DreamHost DreamObjects. It is best suited for power users who are familiar with command line programs. It is also ideal for batch scripts and automated backup to S3, triggered from cron, etc. |
| [s5cmd](https://pypi.python.org/pypi/s3cmd) | s5cmd is a very fast S3 and local filesystem execution tool. It comes with support for a multitude of operations including tab completion and wildcard support for files, which can be very handy for your object storage workflow while working with large number of files. There are already other utilities to work with S3 and similar object storage services, thus it is natural to wonder what s5cmd has to offer that others don't. In short, s5cmd offers a very fast speed. Thanks to Joshua Robinson for his study and experimentation on s5cmd; to quote his medium post: For uploads, s5cmd is 32x faster than s3cmd and 12x faster than aws-cli. For downloads, s5cmd can saturate a 40Gbps link (~4.3 GB/s), whereas s3cmd and aws-cli can only reach 85 MB/s and 375 MB/s respectively. If you would like to know more about performance of s5cmd and the reasons for its fast speed, refer to benchmarks section |
| [SALOME_CONFIGURATION](https://www.salome-platform.org) | Configuration files and other utilities for SALOME platform. |
| [SavvySuite](https://github.com/rdemolgen/SavvySuite/) | Suite of tools for analysing off-target reads to find CNVs, homozygous regions, and shared haplotypes. This software was written by Matthew Wakeling at the University of Exeter, and was presented at the 2017 ASHG meeting in Orlando, Florida. To cite this software, please use the following references. For SavvyCNV, use: https://www.biorxiv.org/content/10.1101/617605v1 For all other parts of SavvySuite, cite the ASHG conference presentation: Wakeling, MN, De Franco E, Hattersley AT, Ellard S. Making the most of targeted sequencing: detecting CNVs and homozygous regions using offtarget reads with SavvyCNV. 67th Annual Meeting of the American Society of Human Genetics. Orlando, FL; 17–21 October 2017. and if desired, cite this web site too: Wakeling MN. SavvySuite. 2018. https://github.com/rdemolgen/SavvySuite. |
| [SDE](https://software.intel.com/en-us/articles/intel-software-development-emulator) | Intel Software Development Emulator is a pintool that enables the development of applications using instruction set extensions that are not currently implemented in hardware. |
| [SoX](https://sourceforge.net/projects/sox) | SoX is the Swiss Army Knife of sound processing utilities. It can convert audio files to other popular audio file types and also apply sound effects and filters during the conversion. |
| [Szip](https://www.hdfgroup.org/doc_resource/SZIP/) | Szip compression software, providing lossless compression of scientific data |
| [tcsh](https://www.tcsh.org) | Tcsh is an enhanced, but completely compatible version of the Berkeley UNIX C shell (csh). It is a command language interpreter usable both as an interactive login shell and a shell script command processor. It includes a command-line editor, programmable word completion, spelling correction, a history mechanism, job control and a C-like syntax. |
| [time](https://www.gnu.org/software/time/) | The `time' command runs another program, then displays information about the resources used by that program, collected by the system while the program was running. |
| [TOML-Fortran](https://github.com/toml-f/toml-f) | TOML parser for Fortran projects |
| [UnZip](http://www.info-zip.org/UnZip.html) | UnZip is an extraction utility for archives compressed in .zip format (also called "zipfiles"). Although highly compatible both with PKWARE's PKZIP and PKUNZIP utilities for MS-DOS and with Info-ZIP's own Zip program, our primary objectives have been portability and non-MSDOS functionality. |
| [util-linux](https://www.kernel.org/pub/linux/utils/util-linux) | Set of Linux utilities |
| [vaspkit](https://vaspkit.com/) | VASPKIT aims at providing a powerful and user-friendly interface to perform high throughput analysis of various material properties from the raw calculated data using the widely-used VASP code. |
| [Vim](http://www.vim.org) | Vim is an advanced text editor that seeks to provide the power of the de-facto Unix editor 'Vi', with a more complete feature set. |
| [VirtualGL](http://www.virtualgl.org) | VirtualGL is an open source toolkit that gives any Unix or Linux remote display software the ability to run OpenGL applications with full 3D hardware acceleration. |
| [VTune](https://software.intel.com/en-us/vtune) | Intel VTune Amplifier XE is the premier performance profiler for C, C++, C#, Fortran, Assembly and Java. |
| WRF | Old module, description not available. |
| XALT | Old module, description not available. |
| [xxd](https://www.vim.org) | xxd is part of the VIM package and this will only install xxd, not vim! xxd converts to/from hexdumps of binary files. |
| [XZ](https://tukaani.org/xz/) | xz: XZ utilities |
| [Z3](https://github.com/Z3Prover/z3) | Z3 is a theorem prover from Microsoft Research. |
| [Zip](http://www.info-zip.org/Zip.html) | Zip is a compression and file packaging/archive utility. Although highly compatible both with PKWARE's PKZIP and PKUNZIP utilities for MS-DOS and with Info-ZIP's own UnZip, our primary objectives have been portability and other-than-MSDOS functionality |

## Vis

| Module | Description |
| ------ | ----------- |
| [at-spi2-atk](https://wiki.gnome.org/Accessibility) | AT-SPI 2 toolkit bridge |
| [at-spi2-core](https://wiki.gnome.org/Accessibility) | Assistive Technology Service Provider Interface. |
| [ATK](https://developer.gnome.org/atk/) | ATK provides the set of accessibility interfaces that are implemented by other toolkits and applications. Using the ATK interfaces, accessibility tools have full access to view and control running applications. |
| [Blender](https://www.blender.org/) | Blender is the free and open source 3D creation suite. It supports the entirety of the 3D pipeline-modeling, rigging, animation, simulation, rendering, compositing and motion tracking, even video editing and game creation. |
| [bwidget](https://core.tcl-lang.org/bwidget/home) | The BWidget Toolkit is a high-level Widget Set for Tcl/Tk built using native Tcl/Tk 8.x namespaces. |
| [cairo](https://cairographics.org) | Cairo is a 2D graphics library with support for multiple output devices. Currently supported output targets include the X Window System (via both Xlib and XCB), Quartz, Win32, image buffers, PostScript, PDF, and SVG file output. Experimental backends include OpenGL, BeOS, OS/2, and DirectFB |
| [FFmpeg](https://www.ffmpeg.org/) | A complete, cross-platform solution to record, convert and stream audio and video. |
| [FLTK](https://www.fltk.org) | FLTK is a cross-platform C++ GUI toolkit for UNIX/Linux (X11), Microsoft Windows, and MacOS X. FLTK provides modern GUI functionality without the bloat and supports 3D graphics via OpenGL and its built-in GLUT emulation. |
| [fontconfig](https://www.freedesktop.org/wiki/Software/fontconfig/) | Fontconfig is a library designed to provide system-wide font configuration, customization and application access. |
| [freetype](https://www.freetype.org) | FreeType 2 is a software font engine that is designed to be small, efficient, highly customizable, and portable while capable of producing high-quality output (glyph images). It can be used in graphics libraries, display servers, font conversion tools, text image generation tools, and many other products as well. |
| [Gdk-Pixbuf](https://developer.gnome.org/gdk-pixbuf/stable/) | The Gdk Pixbuf is a toolkit for image loading and pixel buffer manipulation. It is used by GTK+ 2 and GTK+ 3 to load and manipulate images. In the past it was distributed as part of GTK+ 2 but it was split off into a separate package in preparation for the change to GTK+ 3. |
| [gettext](http://www.gnu.org/software/gettext/) | GNU `gettext' is an important step for the GNU Translation Project, as it is an asset on which we may build many other steps. This package offers to programmers, translators, and even users, a well integrated set of tools and documentation |
| [GLib](https://www.gtk.org/) | GLib is one of the base libraries of the GTK+ project |
| [gnuplot](http://gnuplot.sourceforge.net/) | Portable interactive, function plotting utility |
| [grace](https://plasma-gate.weizmann.ac.il/Grace/) | Grace is a WYSIWYG 2D plotting tool for X Windows System and Motif. |
| [GST-plugins-base](https://gstreamer.freedesktop.org/) | GStreamer is a library for constructing graphs of media-handling components. The applications it supports range from simple Ogg/Vorbis playback, audio/video streaming to complex audio (mixing) and video (non-linear editing) processing. |
| [GStreamer](https://gstreamer.freedesktop.org/) | GStreamer is a library for constructing graphs of media-handling components. The applications it supports range from simple Ogg/Vorbis playback, audio/video streaming to complex audio (mixing) and video (non-linear editing) processing. |
| [GTK3](https://developer.gnome.org/gtk3/stable/) | GTK+ is the primary library used to construct user interfaces in GNOME. It provides all the user interface controls, or widgets, used in a common graphical application. Its object-oriented API allows you to construct user interfaces without dealing with the low-level details of drawing and device interaction. |
| [HarfBuzz](https://www.freedesktop.org/wiki/Software/HarfBuzz) | HarfBuzz is an OpenType text shaping engine. |
| [ImageMagick](https://www.imagemagick.org/) | ImageMagick is a software suite to create, edit, compose, or convert bitmap images |
| [JasPer](https://www.ece.uvic.ca/~frodo/jasper/) | The JasPer Project is an open-source initiative to provide a free software-based reference implementation of the codec specified in the JPEG-2000 Part-1 standard. |
| [jbigkit](https://www.cl.cam.ac.uk/~mgk25/jbigkit/) | JBIG-KIT is a software implementation of the JBIG1 data compression standard (ITU-T T.82), which was designed for bi-level image data, such as scanned documents. |
| [libGLU](https://mesa.freedesktop.org/archive/glu/) | The OpenGL Utility Library (GLU) is a computer graphics library for OpenGL. |
| [LittleCMS](https://www.littlecms.com/) | Little CMS intends to be an OPEN SOURCE small-footprint color management engine, with special focus on accuracy and performance. |
| [matplotlib](https://matplotlib.org) | matplotlib is a python 2D plotting library which produces publication quality figures in a variety of hardcopy formats and interactive environments across platforms. matplotlib can be used in python scripts, the python and ipython shell, web application servers, and six graphical user interface toolkits. |
| [Mesa](https://www.mesa3d.org/) | Mesa is an open-source implementation of the OpenGL specification - a system for rendering interactive 3D graphics. |
| [motif](https://motif.ics.com/) | Motif refers to both a graphical user interface (GUI) specification and the widget toolkit for building applications that follow that specification under the X Window System on Unix and other POSIX-compliant systems. It was the standard toolkit for the Common Desktop Environment and thus for Unix. |
| [OpenCV](https://opencv.org/) | OpenCV (Open Source Computer Vision Library) is an open source computer vision and machine learning software library. OpenCV was built to provide a common infrastructure for computer vision applications and to accelerate the use of machine perception in the commercial products. Includes extra modules for OpenCV from the contrib repository. |
| [OpenEXR](https://www.openexr.com/) | OpenEXR is a high dynamic-range (HDR) image file format developed by Industrial Light & Magic for use in computer imaging applications |
| [OptiX](https://developer.nvidia.com/optix) | OptiX is NVIDIA SDK for easy ray tracing performance. It provides a simple framework for accessing the GPU’s massive ray tracing power using state-of-the-art GPU algorithms. |
| [OVITO](https://www.ovito.org/) | OVITO is a scientific visualization and analysis software for atomistic and particle simulation data. |
| [Pango](https://www.pango.org/) | Pango is a library for laying out and rendering of text, with an emphasis on internationalization. Pango can be used anywhere that text layout is needed, though most of the work on Pango so far has been done in the context of the GTK+ widget toolkit. Pango forms the core of text and font handling for GTK+-2.x. |
| [ParaView](https://www.paraview.org) | ParaView is a scientific parallel visualizer. |
| [Pillow](https://pillow.readthedocs.org/) | Pillow is the 'friendly PIL fork' by Alex Clark and Contributors. PIL is the Python Imaging Library by Fredrik Lundh and Contributors. |
| [Pillow-SIMD](https://github.com/uploadcare/pillow-simd) | Pillow is the 'friendly PIL fork' by Alex Clark and Contributors. PIL is the Python Imaging Library by Fredrik Lundh and Contributors. |
| [pixman](http://www.pixman.org/) | Pixman is a low-level software library for pixel manipulation, providing features such as image local_compositing and trapezoid rasterization. Important users of pixman are the cairo graphics library and the X server. |
| [plotly.py](https://plot.ly/python) | An open-source, interactive graphing library for Python |
| [POV-Ray](https://www.povray.org/) | The Persistence of Vision Raytracer, or POV-Ray, is a ray tracing program which generates images from a text-based scene description, and is available for a variety of computer platforms. POV-Ray is a high-quality, Free Software tool for creating stunning three-dimensional graphics. The source code is available for those wanting to do their own ports. |
| [QtiPlot](https://www.qtiplot.com/) | QtiPlot is a cross-platform scientific application for data analysis and visualisation. |
| [Tk](http://www.tcl.tk/) | Tk is an open source, cross-platform widget toolchain that provides a library of basic elements for building a graphical user interface (GUI) in many different programming languages. |
| [Togl](https://sourceforge.net/projects/togl/) | A Tcl/Tk widget for OpenGL rendering. |
| [VESTA](http://www.jp-minerals.org/vesta) | VESTA is a 3D visualization program for structured models, volumetric data such as electron/nuclear densities, and crystal morphologies. |
| [VirtualGL](https://virtualgl.org/) | VirtualGL is an open source toolkit that gives any Linux or Unix remote display software the ability to run OpenGL applications with full hardware acceleration. |
| [VisIt](https://wci.llnl.gov/simulation/local_computer-codes/visit) | VisIt is an Open Source, interactive, scalable, visualization, animation and analysis tool |
| [VMD](https://www.ks.uiuc.edu/Research/vmd) | VMD is a molecular visualization program for displaying, animating, and analyzing large biomolecular systems using 3-D graphics and built-in scripting. |
| [VTK](https://www.vtk.org) | The Visualization Toolkit (VTK) is an open-source, freely available software system for 3D computer graphics, image processing and visualization. VTK consists of a C++ class library and several interpreted interface layers including Tcl/Tk, Java, and Python. VTK supports a wide variety of visualization algorithms including: scalar, vector, tensor, texture, and volumetric methods; and advanced modeling techniques such as: implicit modeling, polygon reduction, mesh smoothing, cutting, contouring, and Delaunay triangulation. |
| [Wayland](https://wayland.freedesktop.org/) | Wayland is a project to define a protocol for a compositor to talk to its clients as well as a library implementation of the protocol. The compositor can be a standalone display server running on Linux kernel modesetting and evdev input devices, an X application, or a wayland client itself. The clients can be traditional applications, X servers (rootless or fullscreen) or other display servers. |
| [wxWidgets](https://www.wxwidgets.org) | wxWidgets is a C++ library that lets developers create applications for Windows, Mac OS X, Linux and other platforms with a single code base. It has popular language bindings for Python, Perl, Ruby and many other languages, and unlike other cross-platform toolkits, wxWidgets gives applications a truly native look and feel because it uses the platform's native API rather than emulating the GUI. |
| [X11](https://www.x.org) | The X Window System (X11) is a windowing system for bitmap displays |
| [x264](https://www.videolan.org/developers/x264.html) | x264 is a free software library and application for encoding video streams into the H.264/MPEG-4 AVC compression format, and is released under the terms of the GNU GPL. |
| [x265](https://x265.org/) | x265 is a free software library and application for encoding video streams into the H.265 AVC compression format, and is released under the terms of the GNU GPL. |
| [XCrySDen](http://www.xcrysden.org/) | XCrySDen is a crystalline and molecular structure visualisation program aiming at display of isosurfaces and contours, which can be superimposed on crystalline structures and interactively rotated and manipulated. |
| [xprop](https://www.x.org/wiki/) | The xprop utility is for displaying window and font properties in an X server. One window or font is selected using the command line arguments or possibly in the case of a window, by clicking on the desired window. A list of properties is then given, possibly with formatting information. |
| [Xvfb](https://www.x.org/releases/X11R7.6/doc/man/man1/Xvfb.1.xhtml) | Xvfb is an X server that can run on machines with no display hardware and no physical input devices. It emulates a dumb framebuffer using virtual memory. |
